@@ -3,7 +3,7 @@
 asammdf utility functions and classes
 """
 
-from collections import namedtuple
+from functools import lru_cache
 from io import BytesIO
 import logging
 from pathlib import Path
@@ -16,25 +16,43 @@ import sys
 from tempfile import TemporaryDirectory
 import xml.etree.ElementTree as ET
 
-from cchardet import detect
+try:
+    from cchardet import detect
+except:
+    try:
+        from chardet import detect
+    except:
+
+        def detect(text):
+            for encoding in ("utf-8", "latin-1", "cp1250", "cp1252"):
+                try:
+                    text.decode(encoding)
+                    break
+                except:
+                    continue
+            else:
+                encoding = None
+            return {"encoding": encoding}
+
+
 import numpy as np
 from numpy import arange, interp, where
-from numpy.core.records import fromarrays
 from pandas import Series
 
 from . import v2_v3_constants as v3c
 from . import v4_constants as v4c
 
 try:
-    from canmatrix.dbc import load as dbc_load
     from canmatrix.arxml import load as arxml_load
+    from canmatrix.dbc import load as dbc_load
 except ModuleNotFoundError:
-    from canmatrix.formats.dbc import load as dbc_load
     from canmatrix.formats.arxml import load as arxml_load
+    from canmatrix.formats.dbc import load as dbc_load
 
 
 UINT8_u = Struct("<B").unpack
 UINT16_u = Struct("<H").unpack
+UINT32_p = Struct("<I").pack
 UINT32_u = Struct("<I").unpack
 UINT64_u = Struct("<Q").unpack
 UINT8_uf = Struct("<B").unpack_from
@@ -45,6 +63,8 @@ FLOAT64_u = Struct("<d").unpack
 FLOAT64_uf = Struct("<d").unpack_from
 TWO_UINT64_u = Struct("<2Q").unpack
 TWO_UINT64_uf = Struct("<2Q").unpack_from
+BLK_COMMON_uf = Struct("<4s4xQ").unpack_from
+BLK_COMMON_u = Struct("<4s4xQ8x").unpack
 
 _xmlns_pattern = re.compile(' xmlns="[^"]*"')
 
@@ -57,7 +77,6 @@ __all__ = [
     "ChannelsDB",
     "UniqueDB",
     "MdfException",
-    "SignalSource",
     "get_fmt_v3",
     "get_fmt_v4",
     "get_text_v4",
@@ -136,7 +155,7 @@ def extract_cncomment_xml(comment):
 
 
 def matlab_compatible(name):
-    """ make a channel name compatible with Matlab variable naming
+    """make a channel name compatible with Matlab variable naming
 
     Parameters
     ----------
@@ -162,7 +181,7 @@ def matlab_compatible(name):
 
 
 def get_text_v3(address, stream, mapped=False, decode=True):
-    """ faster way to extract strings from mdf versions 2 and 3 TextBlock
+    """faster way to extract strings from mdf versions 2 and 3 TextBlock
 
     Parameters
     ----------
@@ -198,8 +217,11 @@ def get_text_v3(address, stream, mapped=False, decode=True):
         try:
             text = text_bytes.decode("latin-1")
         except UnicodeDecodeError:
-            encoding = detect(text_bytes)["encoding"]
-            text = text_bytes.decode(encoding, "ignore")
+            try:
+                encoding = detect(text_bytes)["encoding"]
+                text = text_bytes.decode(encoding, "ignore")
+            except:
+                text = "<!text_decode_error>"
     else:
         text = text_bytes
 
@@ -207,7 +229,7 @@ def get_text_v3(address, stream, mapped=False, decode=True):
 
 
 def get_text_v4(address, stream, mapped=False, decode=True):
-    """ faster way to extract strings from mdf version 4 TextBlock
+    """faster way to extract strings from mdf version 4 TextBlock
 
     Parameters
     ----------
@@ -227,24 +249,26 @@ def get_text_v4(address, stream, mapped=False, decode=True):
         return "" if decode else b""
 
     if mapped:
-        block_id = stream[address : address + 4]
+        block_id, size = BLK_COMMON_uf(stream, address)
         if block_id not in (b"##TX", b"##MD"):
             return "" if decode else b""
-        (size,) = UINT64_uf(stream, address + 8)
         text_bytes = stream[address + 24 : address + size].strip(b" \r\t\n\0")
     else:
         stream.seek(address)
-        block_id = stream.read(8)[:4]
+        block_id, size = BLK_COMMON_u(stream.read(24))
         if block_id not in (b"##TX", b"##MD"):
             return "" if decode else b""
-        size, _ = TWO_UINT64_u(stream.read(16))
         text_bytes = stream.read(size - 24).strip(b" \r\t\n\0")
+
     if decode:
         try:
             text = text_bytes.decode("utf-8")
         except UnicodeDecodeError:
-            encoding = detect(text_bytes)["encoding"]
-            text = text_bytes.decode(encoding, "ignore")
+            try:
+                encoding = detect(text_bytes)["encoding"]
+                text = text_bytes.decode(encoding, "ignore")
+            except:
+                text = "<!text_decode_error>"
     else:
         text = text_bytes
 
@@ -255,6 +279,7 @@ def sanitize_xml(text):
     return re.sub(_xmlns_pattern, "", text)
 
 
+@lru_cache(maxsize=1024)
 def get_fmt_v3(data_type, size, byte_order=v3c.BYTE_ORDER_INTEL):
     """convert mdf versions 2 and 3 channel data type to numpy dtype format
     string
@@ -338,6 +363,7 @@ def get_fmt_v3(data_type, size, byte_order=v3c.BYTE_ORDER_INTEL):
     return fmt
 
 
+@lru_cache(maxsize=1024)
 def get_fmt_v4(data_type, size, channel_type=v4c.CHANNEL_TYPE_VALUE):
     """convert mdf version 4 channel data type to numpy dtype format string
 
@@ -381,6 +407,29 @@ def get_fmt_v4(data_type, size, channel_type=v4c.CHANNEL_TYPE_VALUE):
         elif data_type == v4c.DATA_TYPE_CANOPEN_TIME:
             fmt = "V6"
 
+    elif channel_type in v4c.VIRTUAL_TYPES:
+        if data_type == v4c.DATA_TYPE_UNSIGNED_INTEL:
+            fmt = "<u8"
+
+        elif data_type == v4c.DATA_TYPE_UNSIGNED_MOTOROLA:
+            fmt = ">u8"
+
+        elif data_type == v4c.DATA_TYPE_SIGNED_INTEL:
+            fmt = "<i8"
+
+        elif data_type == v4c.DATA_TYPE_SIGNED_MOTOROLA:
+            fmt = ">i8"
+
+        elif data_type == v4c.DATA_TYPE_REAL_INTEL:
+            fmt = "<f8"
+
+        elif data_type == v4c.DATA_TYPE_REAL_MOTOROLA:
+            fmt = ">f8"
+        elif data_type == v4c.DATA_TYPE_COMPLEX_INTEL:
+            fmt = "<c8"
+        elif data_type == v4c.DATA_TYPE_COMPLEX_MOTOROLA:
+            fmt = ">c8"
+
     else:
         if size > 64 and data_type in (
             v4c.DATA_TYPE_UNSIGNED_INTEL,
@@ -424,6 +473,7 @@ def get_fmt_v4(data_type, size, channel_type=v4c.CHANNEL_TYPE_VALUE):
     return fmt
 
 
+@lru_cache(maxsize=1024)
 def fmt_to_datatype_v3(fmt, shape, array=False):
     """convert numpy dtype format string to mdf versions 2 and 3
     channel data type and size
@@ -488,6 +538,7 @@ def fmt_to_datatype_v3(fmt, shape, array=False):
     return data_type, size
 
 
+@lru_cache(maxsize=1024)
 def info_to_datatype_v4(signed, little_endian):
     """map CAN signal to MDF integer types
 
@@ -519,6 +570,7 @@ def info_to_datatype_v4(signed, little_endian):
     return datatype
 
 
+@lru_cache(maxsize=1024)
 def fmt_to_datatype_v4(fmt, shape, array=False):
     """convert numpy dtype format string to mdf version 4 channel data
     type and size
@@ -622,7 +674,7 @@ def as_non_byte_sized_signed_int(integer_array, bit_length):
 
 
 def debug_channel(mdf, group, channel, dependency, file=None):
-    """ use this to print debug information in case of errors
+    """use this to print debug information in case of errors
 
     Parameters
     ----------
@@ -668,7 +720,7 @@ def debug_channel(mdf, group, channel, dependency, file=None):
 
 
 def count_channel_groups(stream, include_channels=False):
-    """ count all channel groups as fast as possible. This is used to provide
+    """count all channel groups as fast as possible. This is used to provide
     reliable progress information when loading a file using the GUI
 
     Parameters
@@ -745,7 +797,7 @@ def count_channel_groups(stream, include_channels=False):
 
 
 def validate_version_argument(version, hint=4):
-    """ validate the version argument against the supported MDF versions. The
+    """validate the version argument against the supported MDF versions. The
     default version used depends on the hint MDF major revision
 
     Parameters
@@ -785,7 +837,7 @@ class ChannelsDB(dict):
         super().__init__()
 
     def add(self, channel_name, entry):
-        """ add name to channels database and check if it contains a source
+        """add name to channels database and check if it contains a source
         path
 
         Parameters
@@ -812,7 +864,7 @@ class ChannelsDB(dict):
 
 
 def randomized_string(size):
-    """ get a \0 terminated string of size length
+    """get a \0 terminated string of size length
 
     Parameters
     ----------
@@ -870,7 +922,7 @@ class UniqueDB(object):
         self._db = {}
 
     def get_unique_name(self, name):
-        """ returns an available unique name
+        """returns an available unique name
 
         Parameters
         ----------
@@ -894,7 +946,7 @@ class UniqueDB(object):
 
 
 def cut_video_stream(stream, start, end, fmt):
-    """ cut video stream from `start` to `end` time
+    """cut video stream from `start` to `end` time
 
     Parameters
     ----------
@@ -1031,10 +1083,10 @@ class Group:
 
 
 class VirtualChannelGroup:
-    """ starting with MDF v4.20 it is possible to use remote masters and column
+    """starting with MDF v4.20 it is possible to use remote masters and column
     oriented storage. This means we now have virtual channel groups that can
     span over multiple regular channel groups. This class facilitates the
-    handling of this virtual groups """
+    handling of this virtual groups"""
 
     __slots__ = (
         "groups",
@@ -1067,9 +1119,9 @@ def block_fields(obj):
 
 
 def components(
-    channel, channel_name, unique_names, prefix="", master=None, only_basenames=False,
+    channel, channel_name, unique_names, prefix="", master=None, only_basenames=False
 ):
-    """ yield pandas Series and unique name based on the ndarray object
+    """yield pandas Series and unique name based on the ndarray object
 
     Parameters
     ----------
@@ -1129,13 +1181,10 @@ def components(
             else:
                 axis_name = unique_names.get_unique_name(name)
             if len(values.shape) > 1:
-                arr = [values]
-                types = [("", values.dtype, values.shape[1:])]
                 values = Series(
-                    fromarrays(arr, dtype=types),
+                    list(values),
                     index=master,
                 )
-                del arr
             else:
                 values = Series(
                     values,
@@ -1323,7 +1372,7 @@ def downcast(array):
 
 
 def master_using_raster(mdf, raster, endpoint=False):
-    """ get single master based on the raster
+    """get single master based on the raster
 
     Parameters
     ----------
@@ -1351,12 +1400,12 @@ def master_using_raster(mdf, raster, endpoint=False):
             cycles_nr = group.channel_group.cycles_nr
             if cycles_nr:
                 master_min = mdf.get_master(
-                    group_index, record_offset=0, record_count=1,
+                    group_index, record_offset=0, record_count=1
                 )
                 if len(master_min):
                     t_min.append(master_min[0])
                 master_max = mdf.get_master(
-                    group_index, record_offset=cycles_nr - 1, record_count=1,
+                    group_index, record_offset=cycles_nr - 1, record_count=1
                 )
                 if len(master_max):
                     t_max.append(master_max[0])
@@ -1379,8 +1428,21 @@ def master_using_raster(mdf, raster, endpoint=False):
     return master
 
 
+def csv_int2bin(val):
+    """format CAN id as bin
+
+    100 -> 1100100
+
+    """
+
+    return f"{val:b}"
+
+
+csv_int2bin = np.vectorize(csv_int2bin, otypes=[str])
+
+
 def csv_int2hex(val):
-    """ format CAN id as hex
+    """format CAN id as hex
 
     100 -> 64
 
@@ -1392,13 +1454,16 @@ def csv_int2hex(val):
 csv_int2hex = np.vectorize(csv_int2hex, otypes=[str])
 
 
-def csv_bytearray2hex(val):
-    """ format CAN payload as hex strings
+def csv_bytearray2hex(val, size=None):
+    """format CAN payload as hex strings
 
     b'\xa2\xc3\x08' -> A2 C3 08
 
     """
-    val = val.tobytes().hex().upper()
+    if size is not None:
+        val = val.tobytes()[:size].hex().upper()
+    else:
+        val = val.tobytes().hex().upper()
 
     vals = [val[i : i + 2] for i in range(0, len(val), 2)]
 
@@ -1499,7 +1564,7 @@ def all_blocks_addresses(obj):
 
 
 def plausible_timestamps(t, minimum, maximum, exp_min=-15, exp_max=15):
-    """ check if the time stamps are plausible
+    """check if the time stamps are plausible
 
     Parameters
     ----------
