@@ -39,11 +39,7 @@ DATA_TYPE_TO_STRING = {
     DATA_TYPE_DOUBLE_MOTOROLA: "DOUBLE_MOTOROLA",
 }
 
-SIGNED_INT = {
-    DATA_TYPE_SIGNED,
-    DATA_TYPE_SIGNED_INTEL,
-    DATA_TYPE_SIGNED_MOTOROLA,
-}
+SIGNED_INT = {DATA_TYPE_SIGNED, DATA_TYPE_SIGNED_INTEL, DATA_TYPE_SIGNED_MOTOROLA}
 
 FLOATS = {
     DATA_TYPE_FLOAT,
@@ -74,10 +70,7 @@ INT_TYPES = {
 CHANNEL_TYPE_VALUE = 0
 CHANNEL_TYPE_MASTER = 1
 
-CHANNEL_TYPE_TO_STRING = {
-    CHANNEL_TYPE_VALUE: "VALUE",
-    CHANNEL_TYPE_MASTER: "MASTER",
-}
+CHANNEL_TYPE_TO_STRING = {CHANNEL_TYPE_VALUE: "VALUE", CHANNEL_TYPE_MASTER: "MASTER"}
 
 # channel conversion types
 CONVERSION_TYPE_NONE = 65535
@@ -129,10 +122,7 @@ FLAG_VAL_RANGE_OK = 8
 SOURCE_ECU = 2
 SOURCE_VECTOR = 19
 
-SOURCE_TYPE_TO_STRING = {
-    SOURCE_ECU: "ECU",
-    SOURCE_VECTOR: "VECTOR",
-}
+SOURCE_TYPE_TO_STRING = {SOURCE_ECU: "ECU", SOURCE_VECTOR: "VECTOR"}
 
 # bus types
 BUS_TYPE_NONE = 0
