@@ -98,7 +98,7 @@ SYNC_TYPE_ANGLE = 2
 SYNC_TYPE_DISTANCE = 3
 SYNC_TYPE_INDEX = 4
 
-SYNC_TYPE_TO_STRING = dict(enumerate(["NONE", "TIME", "ANGLE", "DISTANCE", "INDEX",]))
+SYNC_TYPE_TO_STRING = dict(enumerate(["NONE", "TIME", "ANGLE", "DISTANCE", "INDEX"]))
 
 CHANNEL_TYPE_TO_STRING = CHANNEL_TYPE_TO_DESCRIPTION = {
     CHANNEL_TYPE_VALUE: "VALUE",
@@ -549,7 +549,7 @@ COMMON_u = struct.Struct(FMT_COMMON).unpack
 COMMON_uf = struct.Struct(FMT_COMMON).unpack_from
 COMMON_p = struct.Struct(FMT_COMMON).pack
 
-FMT_COMMON_SHORT = "<4sIQ"
+FMT_COMMON_SHORT = "<4s4xQ"
 COMMON_SHORT_u = struct.Struct(FMT_COMMON_SHORT).unpack
 COMMON_SHORT_uf = struct.Struct(FMT_COMMON_SHORT).unpack_from
 COMMON_SHORT_p = struct.Struct(FMT_COMMON_SHORT).pack
@@ -719,10 +719,12 @@ KEYS_DZ_BLOCK = (
     "zip_size",
     "data",
 )
-DZ_COMMON_u = struct.Struct(FMT_DZ_COMMON).unpack
-DZ_COMMON_uf = struct.Struct(FMT_DZ_COMMON).unpack_from
 DZ_COMMON_p = struct.Struct(FMT_DZ_COMMON).pack
 
+FMT_DZ_INFO_COMMON = "<24x2sB1xI2Q"
+DZ_COMMON_INFO_u = struct.Struct(FMT_DZ_INFO_COMMON).unpack
+DZ_COMMON_INFO_uf = struct.Struct(FMT_DZ_INFO_COMMON).unpack_from
+
 FMT_HL_BLOCK = "<4sI3QHB5s"
 KEYS_HL_BLOCK = (
     "id",
@@ -757,6 +759,7 @@ ASAM_XML_NAMESPACE = "{http://www.asam.net/mdf/v4}"
 
 CAN_ID_PATTERN = re.compile(r"(?i:can)(?P<id>\d+)")
 CAN_DATA_FRAME_PATTERN = re.compile(r"(?i:CAN_DataFrame)_(?P<id>\d+)")
+LIN_DATA_FRAME_PATTERN = re.compile(r"(?i:LIN_Frame)_(?P<id>\d+)")
 
 CN_COMMENT_TEMPLATE = """<CNcomment>
 <TX>{}</TX>
