@@ -11,13 +11,10 @@ sys.excepthook = excepthook
 
 
 def _cmd_line_parser():
-    """
-    """
+    """"""
 
     parser = argparse.ArgumentParser()
-    parser.add_argument(
-        "--measurements", nargs="*", help="list of measurement files",
-    )
+    parser.add_argument("--measurements", nargs="*", help="list of measurement files")
     return parser
 
 
