@@ -5,17 +5,13 @@ import json
 import os
 from pathlib import Path
 from tempfile import gettempdir
-from time import perf_counter
-from traceback import format_exc
 
 from natsort import natsorted
-import numpy as np
-import pandas as pd
 import psutil
 from PyQt5 import QtCore, QtGui, QtWidgets
 import pyqtgraph as pg
 
-from ...blocks.utils import csv_bytearray2hex, extract_cncomment_xml, MdfException
+from ...blocks.utils import extract_cncomment_xml
 from ...blocks.v4_constants import FLAG_AT_TO_STRING, FLAG_CG_BUS_EVENT
 from ...mdf import MDF, SUPPORTED_VERSIONS
 from ..dialogs.advanced_search import AdvancedSearch
@@ -25,8 +21,6 @@ from ..ui import resource_rc as resource_rc
 from ..ui.file_widget import Ui_file_widget
 from ..utils import (
     add_children,
-    compute_signal,
-    get_required_signals,
     HelperChannel,
     load_dsp,
     load_lab,
@@ -38,7 +32,6 @@ from .attachment import Attachment
 from .mdi_area import MdiAreaWidget, WithMDIArea
 from .numeric import Numeric
 from .plot import Plot
-from .tree import TreeWidget
 from .tree_item import TreeItem
 
 
@@ -97,7 +90,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
             extension = file_name.suffix.lower().strip(".")
             progress.setLabelText(f"Converting from {extension} to mdf")
 
-            from mfile import ERG, BSIG
+            from mfile import BSIG, ERG
 
             if file_name.suffix.lower() == ".erg":
                 cls = ERG
@@ -213,23 +206,24 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
         self.mdf_compression.insertItems(
             0, ("no compression", "deflate", "transposed deflate")
         )
-        self.mdf_split_size.setValue(10)
+        self.mdf_split_size.setValue(4)
 
-        self.extract_can_format.insertItems(0, SUPPORTED_VERSIONS)
-        index = self.extract_can_format.findText(self.mdf.version)
+        self.extract_bus_format.insertItems(0, SUPPORTED_VERSIONS)
+        index = self.extract_bus_format.findText(self.mdf.version)
         if index >= 0:
-            self.extract_can_format.setCurrentIndex(index)
-        self.extract_can_compression.insertItems(
+            self.extract_bus_format.setCurrentIndex(index)
+        self.extract_bus_compression.insertItems(
             0, ("no compression", "deflate", "transposed deflate")
         )
-        self.extract_can_btn.clicked.connect(self.extract_can_logging)
-        self.extract_can_csv_btn.clicked.connect(self.extract_can_csv_logging)
+        self.extract_bus_btn.clicked.connect(self.extract_bus_logging)
+        self.extract_bus_csv_btn.clicked.connect(self.extract_bus_csv_logging)
         self.load_can_database_btn.clicked.connect(self.load_can_database)
+        self.load_lin_database_btn.clicked.connect(self.load_lin_database)
 
         progress.setValue(99)
 
         self.empty_channels.insertItems(0, ("skip", "zeros"))
-        self.empty_channels_can.insertItems(0, ("skip", "zeros"))
+        self.empty_channels_bus.insertItems(0, ("skip", "zeros"))
         self.empty_channels_mat.insertItems(0, ("skip", "zeros"))
         self.mat_format.insertItems(0, ("4", "5", "7.3"))
         self.oned_as.insertItems(0, ("row", "column"))
@@ -346,11 +340,15 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
             item = QtWidgets.QTreeWidgetItem()
             item.setText(0, "Cycles")
             item.setText(1, str(cycles))
+            if cycles:
+                item.setForeground(1, QtGui.QBrush(QtCore.Qt.darkGreen))
             channel_group.addChild(item)
 
             item = QtWidgets.QTreeWidgetItem()
             item.setText(0, "Raw size")
             item.setText(1, f"{size / 1024 / 1024:.1f} MB")
+            if cycles:
+                item.setForeground(1, QtGui.QBrush(QtCore.Qt.darkGreen))
             channel_group.addChild(item)
 
             channel_groups_children.append(channel_group)
@@ -642,7 +640,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
             widget = self.filter_tree
             view = self.filter_view
         dlg = AdvancedSearch(
-            self.mdf.channels_db, show_add_window=show_add_window, parent=self,
+            self.mdf.channels_db, show_add_window=show_add_window, parent=self
         )
         dlg.setModal(True)
         dlg.exec_()
@@ -656,7 +654,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                     "New pattern based tabular window",
                 ]
                 ret, ok = QtWidgets.QInputDialog.getItem(
-                    None, "Select pattern based window type", "Type:", options, 0, False,
+                    None, "Select pattern based window type", "Type:", options, 0, False
                 )
                 if ok:
                     index = options.index(ret)
@@ -666,10 +664,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                             {
                                 "type": "Plot",
                                 "title": result["pattern"],
-                                "configuration": {
-                                    "channels": [],
-                                    "pattern": result,
-                                }
+                                "configuration": {"channels": [], "pattern": result},
                             }
                         )
                     elif index == 1:
@@ -677,10 +672,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                             {
                                 "type": "Numeric",
                                 "title": result["pattern"],
-                                "configuration": {
-                                    "channels": [],
-                                    "pattern": result,
-                                }
+                                "configuration": {"channels": [], "pattern": result},
                             }
                         )
                     elif index == 2:
@@ -695,7 +687,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                                     "time_as_date": False,
                                     "sorted": False,
                                     "filtered": False,
-                                }
+                                },
                             }
                         )
 
@@ -771,12 +763,13 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                         "New tabular window",
                     ] + [mdi.windowTitle() for mdi in self.mdi_area.subWindowList()]
                     ret, ok = QtWidgets.QInputDialog.getItem(
-                        None, "Select window type", "Type:", options, 0, False,
+                        None, "Select window type", "Type:", options, 0, False
                     )
                     if ok:
                         index = options.index(ret)
                         signals = [
-                            (None, *self.mdf.whereis(name)[0], self.uuid) for name in names
+                            (None, *self.mdf.whereis(name)[0], self.uuid)
+                            for name in names
                         ]
 
                         if index == 0:
@@ -1071,7 +1064,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                                 channel.setCheckState(0, QtCore.Qt.Checked)
                                 items.append(channel)
 
-                                channels.pop(channels.index(channel_name))
+                                channels.pop(channels.index(ch.name))
 
                     if len(items) < 30000:
                         items = natsorted(items, key=lambda x: x.name)
@@ -1085,12 +1078,12 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
         for i, group in enumerate(self.mdf.groups):
             cycles_nr = group.channel_group.cycles_nr
             if cycles_nr:
-                master_min = self.mdf.get_master(i, record_offset=0, record_count=1,)
+                master_min = self.mdf.get_master(i, record_offset=0, record_count=1)
                 if len(master_min):
                     t_min.append(master_min[0])
                 self.mdf._master_channel_cache.clear()
                 master_max = self.mdf.get_master(
-                    i, record_offset=cycles_nr - 1, record_count=1,
+                    i, record_offset=cycles_nr - 1, record_count=1
                 )
                 if len(master_max):
                     t_max.append(master_max[0])
@@ -1246,7 +1239,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
         kwargs = {"name": self.file_name, "callback": self.update_progress}
 
         mdf = run_thread_with_progress(
-            self, target=target, kwargs=kwargs, factor=100, offset=0, progress=progress,
+            self, target=target, kwargs=kwargs, factor=100, offset=0, progress=progress
         )
 
         if mdf is TERMINATED:
@@ -1260,18 +1253,28 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
 
         self.open_new_file.emit(str(path.with_suffix(f".scrambled{path.suffix}")))
 
-    def extract_can_logging(self, event):
-        version = self.extract_can_format.currentText()
+    def extract_bus_logging(self, event):
+        version = self.extract_bus_format.currentText()
+
+        self.output_info_bus.setPlainText("")
+
+        database_files = {}
+
         count = self.can_database_list.count()
+        if count:
+            database_files["CAN"] = []
+            for i in range(count):
+                item = self.can_database_list.item(i)
+                database_files["CAN"].append(item.text())
 
-        self.output_info_can.setPlainText("")
+        count = self.lin_database_list.count()
+        if count:
+            database_files["LIN"] = []
+            for i in range(count):
+                item = self.lin_database_list.item(i)
+                database_files["LIN"].append(item.text())
 
-        dbc_files = []
-        for i in range(count):
-            item = self.can_database_list.item(i)
-            dbc_files.append(item.text())
-
-        compression = self.extract_can_compression.currentIndex()
+        compression = self.extract_bus_compression.currentIndex()
         ignore_invalid_signals = (
             self.ignore_invalid_signals_mdf.checkState() == QtCore.Qt.Checked
         )
@@ -1283,6 +1286,9 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
             filter = "MDF version 4 files (*.mf4)"
             suffix = ".mf4"
 
+        if not database_files:
+            return
+
         file_name, _ = QtWidgets.QFileDialog.getSaveFileName(
             self,
             "Select output measurement file",
@@ -1297,15 +1303,15 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
 
             progress = setup_progress(
                 parent=self,
-                title="Extract CAN logging",
-                message=f'Extracting CAN signals from "{self.file_name}"',
+                title="Extract Bus logging",
+                message=f'Extracting Bus signals from "{self.file_name}"',
                 icon_name="down",
             )
 
             # convert self.mdf
-            target = self.mdf.extract_can_logging
+            target = self.mdf.extract_bus_logging
             kwargs = {
-                "dbc_files": dbc_files,
+                "database_files": database_files,
                 "version": version,
                 "ignore_invalid_signals": ignore_invalid_signals,
             }
@@ -1345,61 +1351,76 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
             self.progress = None
             progress.cancel()
 
-            call_info = dict(self.mdf.last_call_info)
+            bus_call_info = dict(self.mdf.last_call_info)
 
-            found_id_count = sum(len(e) for e in call_info["found_ids"].values())
+            message = []
 
-            message = [
-                "Summary:",
-                f'- {found_id_count} of {len(call_info["total_unique_ids"])} IDs in the MDF4 file were matched in the DBC and converted',
-            ]
-            if call_info["unknown_id_count"]:
-                message.append(
-                    f'- {call_info["unknown_id_count"]} unknown IDs in the MDF4 file'
-                )
-            else:
-                message.append(f"- no unknown IDs inf the MDF4 file")
+            for bus, call_info in bus_call_info.items():
 
-            message += [
-                "",
-                "Detailed information:",
-                "",
-                "The following CAN IDs were in the MDF log file and matched in the DBC:",
-            ]
-            for dbc_name, found_ids in call_info["found_ids"].items():
-                for msg_id, msg_name in sorted(found_ids):
-                    message.append(f"- 0x{msg_id:X} --> {msg_name} in <{dbc_name}>")
+                found_id_count = sum(len(e) for e in call_info["found_ids"].values())
 
-            message += [
-                "",
-                "The following CAN IDs were in the MDF log file, but not matched in the DBC:",
-            ]
-            for msg_id in sorted(call_info["unknown_ids"]):
-                message.append(f"- 0x{msg_id:X}")
+                message += [
+                    f"{bus} bus summary:",
+                    f'- {found_id_count} of {len(call_info["total_unique_ids"])} IDs in the MDF4 file were matched in the DBC and converted',
+                ]
+                if call_info["unknown_id_count"]:
+                    message.append(
+                        f'- {call_info["unknown_id_count"]} unknown IDs in the MDF4 file'
+                    )
+                else:
+                    message.append(f"- no unknown IDs inf the MDF4 file")
 
-            self.output_info_can.setPlainText("\n".join(message))
+                message += [
+                    "",
+                    "Detailed information:",
+                    "",
+                    f"The following {bus} IDs were in the MDF log file and matched in the DBC:",
+                ]
+                for dbc_name, found_ids in call_info["found_ids"].items():
+                    for msg_id, msg_name in sorted(found_ids):
+                        message.append(f"- 0x{msg_id:X} --> {msg_name} in <{dbc_name}>")
+
+                message += [
+                    "",
+                    f"The following {bus} IDs were in the MDF log file, but not matched in the DBC:",
+                ]
+                for msg_id in sorted(call_info["unknown_ids"]):
+                    message.append(f"- 0x{msg_id:X}")
+                message.append("\n\n")
+
+            self.output_info_bus.setPlainText("\n".join(message))
 
             self.open_new_file.emit(str(file_name))
 
-    def extract_can_csv_logging(self, event):
-        version = self.extract_can_format.currentText()
+    def extract_bus_csv_logging(self, event):
+        version = self.extract_bus_format.currentText()
+
+        self.output_info_bus.setPlainText("")
+
+        database_files = {}
+
         count = self.can_database_list.count()
+        if count:
+            database_files["CAN"] = []
+            for i in range(count):
+                item = self.can_database_list.item(i)
+                database_files["CAN"].append(item.text())
 
-        self.output_info_can.setPlainText("")
-
-        dbc_files = []
-        for i in range(count):
-            item = self.can_database_list.item(i)
-            dbc_files.append(item.text())
+        count = self.lin_database_list.count()
+        if count:
+            database_files["LIN"] = []
+            for i in range(count):
+                item = self.lin_database_list.item(i)
+                database_files["LIN"].append(item.text())
 
         ignore_invalid_signals = (
             self.ignore_invalid_signals_csv.checkState() == QtCore.Qt.Checked
         )
-        single_time_base = self.single_time_base_can.checkState() == QtCore.Qt.Checked
-        time_from_zero = self.time_from_zero_can.checkState() == QtCore.Qt.Checked
-        empty_channels = self.empty_channels_can.currentText()
-        raster = self.export_raster.value()
-        time_as_date = self.can_time_as_date.checkState() == QtCore.Qt.Checked
+        single_time_base = self.single_time_base_bus.checkState() == QtCore.Qt.Checked
+        time_from_zero = self.time_from_zero_bus.checkState() == QtCore.Qt.Checked
+        empty_channels = self.empty_channels_bus.currentText()
+        raster = self.export_raster_bus.value()
+        time_as_date = self.bus_time_as_date.checkState() == QtCore.Qt.Checked
 
         file_name, _ = QtWidgets.QFileDialog.getSaveFileName(
             self,
@@ -1413,15 +1434,15 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
 
             progress = setup_progress(
                 parent=self,
-                title="Extract CAN logging to CSV",
-                message=f'Extracting CAN signals from "{self.file_name}"',
+                title="Extract Bus logging to CSV",
+                message=f'Extracting Bus signals from "{self.file_name}"',
                 icon_name="csv",
             )
 
             # convert self.mdf
-            target = self.mdf.extract_can_logging
+            target = self.mdf.extract_bus_logging
             kwargs = {
-                "dbc_files": dbc_files,
+                "database_files": database_files,
                 "version": version,
                 "ignore_invalid_signals": ignore_invalid_signals,
             }
@@ -1449,7 +1470,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                 "single_time_base": single_time_base,
                 "time_from_zero": time_from_zero,
                 "empty_channels": empty_channels,
-                "raster": raster,
+                "raster": raster or None,
                 "time_as_date": time_as_date,
                 "ignore_value2text_conversions": self.ignore_value2text_conversions,
             }
@@ -1466,52 +1487,69 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
             self.progress = None
             progress.cancel()
 
-            call_info = dict(self.mdf.last_call_info)
+            bus_call_info = dict(self.mdf.last_call_info)
 
-            found_id_count = sum(len(e) for e in call_info["found_ids"].values())
+            message = []
 
-            message = [
-                "Summary:",
-                f'- {found_id_count} of {len(call_info["total_unique_ids"])} IDs in the MDF4 file were matched in the DBC and converted',
-            ]
-            if call_info["unknown_id_count"]:
-                message.append(
-                    f'- {call_info["unknown_id_count"]} unknown IDs in the MDF4 file'
-                )
-            else:
-                message.append(f"- no unknown IDs inf the MDF4 file")
+            for bus, call_info in bus_call_info.items():
 
-            message += [
-                "",
-                "Detailed information:",
-                "",
-                "The following CAN IDs were in the MDF log file and matched in the DBC:",
-            ]
-            for dbc_name, found_ids in call_info["found_ids"].items():
-                for msg_id, msg_name in sorted(found_ids):
-                    message.append(f"- 0x{msg_id:X} --> {msg_name} in <{dbc_name}>")
+                found_id_count = sum(len(e) for e in call_info["found_ids"].values())
 
-            message += [
-                "",
-                "The following CAN IDs were in the MDF log file, but not matched in the DBC:",
-            ]
-            for msg_id in sorted(call_info["unknown_ids"]):
-                message.append(f"- 0x{msg_id:X}")
+                message += [
+                    f"{bus} bus summary:",
+                    f'- {found_id_count} of {len(call_info["total_unique_ids"])} IDs in the MDF4 file were matched in the DBC and converted',
+                ]
+                if call_info["unknown_id_count"]:
+                    message.append(
+                        f'- {call_info["unknown_id_count"]} unknown IDs in the MDF4 file'
+                    )
+                else:
+                    message.append(f"- no unknown IDs inf the MDF4 file")
 
-            self.output_info_can.setPlainText("\n".join(message))
+                message += [
+                    "",
+                    "Detailed information:",
+                    "",
+                    f"The following {bus} IDs were in the MDF log file and matched in the DBC:",
+                ]
+                for dbc_name, found_ids in call_info["found_ids"].items():
+                    for msg_id, msg_name in sorted(found_ids):
+                        message.append(f"- 0x{msg_id:X} --> {msg_name} in <{dbc_name}>")
+
+                message += [
+                    "",
+                    f"The following {bus} IDs were in the MDF log file, but not matched in the DBC:",
+                ]
+                for msg_id in sorted(call_info["unknown_ids"]):
+                    message.append(f"- 0x{msg_id:X}")
+                message.append("\n\n")
+
+            self.output_info_bus.setPlainText("\n".join(message))
 
     def load_can_database(self, event):
         file_names, _ = QtWidgets.QFileDialog.getOpenFileNames(
             self,
             "Select CAN database file",
             "",
-            "ARXML or DBC (*.dbc *.axml)",
-            "ARXML or DBC (*.dbc *.axml)",
+            "ARXML or DBC (*.dbc *.arxml)",
+            "ARXML or DBC (*.dbc *.arxml)",
         )
 
         if file_names:
             self.can_database_list.addItems(file_names)
 
+    def load_lin_database(self, event):
+        file_names, _ = QtWidgets.QFileDialog.getOpenFileNames(
+            self,
+            "Select LIN database file",
+            "",
+            "ARXML or DBC (*.dbc *.arxml)",
+            "ARXML or DBC (*.dbc *.arxml)",
+        )
+
+        if file_names:
+            self.lin_database_list.addItems(file_names)
+
     def keyPressEvent(self, event):
         key = event.key()
         modifier = event.modifiers()
@@ -1693,6 +1731,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                 "empty_channels": self.empty_channels_mat.currentText(),
                 "mat_format": self.mat_format.currentText(),
                 "oned_as": self.oned_as.currentText(),
+                "raw": self.raw_mat.checkState() == QtCore.Qt.Checked,
             }
 
         else:
@@ -1710,6 +1749,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                 "empty_channels": self.empty_channels.currentText(),
                 "mat_format": None,
                 "oned_as": None,
+                "raw": self.raw.checkState() == QtCore.Qt.Checked,
             }
 
         options.update(new)
@@ -2100,6 +2140,7 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
                 "compression": opts.compression,
                 "time_as_date": opts.time_as_date,
                 "ignore_value2text_conversions": self.ignore_value2text_conversions,
+                "raw": opts.raw,
             }
 
             result = run_thread_with_progress(
@@ -2115,7 +2156,9 @@ class FileWidget(WithMDIArea, Ui_file_widget, QtWidgets.QWidget):
             progress.cancel()
 
     def raster_search(self, event):
-        dlg = AdvancedSearch(self.mdf.channels_db, show_add_window=False, show_pattern=False, parent=self,)
+        dlg = AdvancedSearch(
+            self.mdf.channels_db, show_add_window=False, show_pattern=False, parent=self
+        )
         dlg.setModal(True)
         dlg.exec_()
         result = dlg.result
