@@ -41,10 +41,12 @@ class ListWidget(QtWidgets.QListWidget):
             deleted = []
             for item in selected_items:
                 row = self.row(item)
-                deleted.append(self.itemWidget(item).uuid)
+                item_widget = self.itemWidget(item)
+                deleted.append(getattr(item_widget, "uuid", None))
                 self.takeItem(row)
             if deleted:
                 self.itemsDeleted.emit(deleted)
+
         elif key == QtCore.Qt.Key_Space and modifiers == QtCore.Qt.NoModifier:
             selected_items = self.selectedItems()
             if not selected_items:
@@ -191,7 +193,7 @@ class ListWidget(QtWidgets.QListWidget):
         menu.addSeparator()
         menu.addAction(self.tr("Delete (Del)"))
         menu.addSeparator()
-        menu.addAction(self.tr("File properties"))
+        menu.addAction(self.tr("File/Computation properties"))
 
         action = menu.exec_(self.viewport().mapToGlobal(position))
 
@@ -200,7 +202,7 @@ class ListWidget(QtWidgets.QListWidget):
 
         if action.text() == "Copy name (Ctrl+C)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier,
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier
             )
             self.itemWidget(item).keyPressEvent(event)
 
@@ -261,7 +263,7 @@ class ListWidget(QtWidgets.QListWidget):
         elif action.text() == "Set unit":
             selected_items = self.selectedItems()
 
-            unit, ok = QtWidgets.QInputDialog.getText(None, "Set new unit", "Unit:",)
+            unit, ok = QtWidgets.QInputDialog.getText(None, "Set new unit", "Unit:")
 
             if ok:
 
@@ -277,7 +279,7 @@ class ListWidget(QtWidgets.QListWidget):
             selected_items = self.selectedItems()
 
             precision, ok = QtWidgets.QInputDialog.getInt(
-                None, "Set new precision (float decimals)", "Precision:",
+                None, "Set new precision (float decimals)", "Precision:"
             )
 
             if ok and 0 <= precision <= 15:
@@ -298,12 +300,12 @@ class ListWidget(QtWidgets.QListWidget):
 
                 if action.text() == "Relative time base shift":
                     offset, ok = QtWidgets.QInputDialog.getDouble(
-                        self, "Relative offset [s]", "Offset [s]:",
+                        self, "Relative offset [s]", "Offset [s]:"
                     )
                     absolute = False
                 else:
                     offset, ok = QtWidgets.QInputDialog.getDouble(
-                        self, "Absolute time start offset [s]", "Offset [s]:",
+                        self, "Absolute time start offset [s]", "Offset [s]:"
                     )
                     absolute = True
                 if ok:
@@ -315,15 +317,15 @@ class ListWidget(QtWidgets.QListWidget):
                         if item in selected_items:
 
                             uuids.append(widget.uuid)
-                    self.set_time_offset.emit([absolute, offset,] + uuids)
+                    self.set_time_offset.emit([absolute, offset] + uuids)
 
         elif action.text() == "Delete (Del)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier,
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier
             )
             self.keyPressEvent(event)
 
-        elif action.text() == "File properties":
+        elif action.text() == "File/Computation properties":
             selected_items = self.selectedItems()
             if len(selected_items) == 1:
                 item = selected_items[0]
@@ -356,6 +358,8 @@ class MinimalListWidget(QtWidgets.QListWidget):
         self.setAcceptDrops(True)
         self.show()
 
+        self.minimal_menu = False
+
     def keyPressEvent(self, event):
         key = event.key()
         modifiers = event.modifiers()
@@ -387,16 +391,22 @@ class MinimalListWidget(QtWidgets.QListWidget):
             super().keyPressEvent(event)
 
     def open_menu(self, position):
+        menu = QtWidgets.QMenu()
 
-        if self.count() == 0:
-            menu = QtWidgets.QMenu()
-            menu.addAction(self.tr("Paste names (Ctrl+V)"))
+        if self.minimal_menu:
+            if self.count() > 0:
+                menu.addAction(self.tr("Delete (Del)"))
+            else:
+                return
         else:
-            menu = QtWidgets.QMenu()
-            menu.addAction(self.tr("Copy names (Ctrl+C)"))
-            menu.addAction(self.tr("Paste names (Ctrl+V)"))
-            menu.addSeparator()
-            menu.addAction(self.tr("Delete (Del)"))
+            if self.count() == 0:
+                menu.addAction(self.tr("Paste names (Ctrl+V)"))
+            else:
+                menu = QtWidgets.QMenu()
+                menu.addAction(self.tr("Copy names (Ctrl+C)"))
+                menu.addAction(self.tr("Paste names (Ctrl+V)"))
+                menu.addSeparator()
+                menu.addAction(self.tr("Delete (Del)"))
 
         action = menu.exec_(self.viewport().mapToGlobal(position))
 
@@ -405,16 +415,16 @@ class MinimalListWidget(QtWidgets.QListWidget):
 
         if action.text() == "Delete (Del)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier,
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier
             )
             self.keyPressEvent(event)
         elif action.text() == "Copy names (Ctrl+C)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier,
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier
             )
             self.keyPressEvent(event)
         elif action.text() == "Paste names (Ctrl+V)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_V, QtCore.Qt.ControlModifier,
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_V, QtCore.Qt.ControlModifier
             )
             self.keyPressEvent(event)
