@@ -1,40 +1,22 @@
 # -*- coding: utf-8 -*-
 from functools import partial
 import gc
-import json
 import os
 from pathlib import Path
 from textwrap import wrap
 import webbrowser
 
 from natsort import natsorted
-import numpy as np
-import pandas as pd
 from PyQt5 import QtCore, QtGui, QtWidgets
 import pyqtgraph as pg
 
-from ...blocks.utils import csv_bytearray2hex, extract_cncomment_xml, MdfException
-from ...mdf import MDF, SUPPORTED_VERSIONS
 from ...version import __version__ as libversion
 from ..dialogs.multi_search import MultiSearch
 from ..ui.main_window import Ui_PyMDFMainWindow
-from ..utils import (
-    add_children,
-    compute_signal,
-    get_required_signals,
-    HelperChannel,
-    load_dsp,
-    run_thread_with_progress,
-    setup_progress,
-    TERMINATED,
-)
 from .batch import BatchWidget
 from .file import FileWidget
-from .list import ListWidget
 from .mdi_area import MdiAreaWidget, WithMDIArea
-from .numeric import Numeric
 from .plot import Plot
-from .tabular import Tabular
 
 
 class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
@@ -375,7 +357,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         action = QtWidgets.QAction("{: <20}\tAlt+R".format("Raw samples"), menu)
         action.triggered.connect(
             partial(
-                self.plot_action, key=QtCore.Qt.Key_R, modifier=QtCore.Qt.AltModifier,
+                self.plot_action, key=QtCore.Qt.Key_R, modifier=QtCore.Qt.AltModifier
             )
         )
         action.setShortcut(QtGui.QKeySequence("Alt+R"))
@@ -384,7 +366,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         action = QtWidgets.QAction("{: <20}\tAlt+S".format("Scaled samples"), menu)
         action.triggered.connect(
             partial(
-                self.plot_action, key=QtCore.Qt.Key_S, modifier=QtCore.Qt.AltModifier,
+                self.plot_action, key=QtCore.Qt.Key_S, modifier=QtCore.Qt.AltModifier
             )
         )
         action.setShortcut(QtGui.QKeySequence("Alt+S"))
@@ -516,7 +498,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         )
         action.triggered.connect(
             partial(
-                self.plot_action, key=QtCore.Qt.Key_I, modifier=QtCore.Qt.AltModifier,
+                self.plot_action, key=QtCore.Qt.Key_I, modifier=QtCore.Qt.AltModifier
             )
         )
         action.setShortcut(QtGui.QKeySequence("Alt+I"))
@@ -575,12 +557,12 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         event = QtGui.QKeyEvent(QtCore.QEvent.KeyPress, key, modifier)
         if self.stackedWidget.currentIndex() == 0:
             widget = self.files.currentWidget()
-            if widget and widget.get_current_plot():
-                widget.get_current_plot().keyPressEvent(event)
+            if widget and widget.get_current_widget():
+                widget.get_current_widget().keyPressEvent(event)
         elif self.stackedWidget.currentIndex() == 2:
             widget = self
-            if widget and widget.get_current_plot():
-                widget.get_current_plot().keyPressEvent(event)
+            if widget and widget.get_current_widget():
+                widget.get_current_widget().keyPressEvent(event)
 
     def toggle_dots(self, key):
         self.with_dots = not self.with_dots
@@ -656,10 +638,10 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         else:
             widget = None
         if widget:
-            plot = widget.get_current_plot()
-            if plot:
-                widget.get_current_plot().plot.x_axis.format = fmt
-                widget.get_current_plot().plot.x_axis.updateAutoSIPrefix()
+            plot = widget.get_current_widget()
+            if plot and isinstance(plot, Plot):
+                widget.get_current_widget().plot.x_axis.format = fmt
+                widget.get_current_widget().plot.x_axis.updateAutoSIPrefix()
                 if plot.plot.cursor1 is not None:
                     plot.cursor_moved()
                 if plot.plot.region is not None:
@@ -1016,7 +998,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                     str(self.files.widget(i).mdf.name) for i in range(count)
                 ]
 
-                dlg = MultiSearch(channels_dbs, measurements, parent=self,)
+                dlg = MultiSearch(channels_dbs, measurements, parent=self)
                 dlg.setModal(True)
                 dlg.exec_()
                 result = dlg.result
@@ -1058,7 +1040,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             info.extend(wrap(f"{i:> 2}: {name}", 120))
 
         QtWidgets.QMessageBox.information(
-            self, "Measurement files used for comparison", "\n".join(info),
+            self, "Measurement files used for comparison", "\n".join(info)
         )
 
     def toggle_fullscreen(self):
