@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
-from datetime import datetime
 from functools import partial
 import json
-import re
 import os
+import re
 from traceback import format_exc
 
 from natsort import natsorted
@@ -13,24 +12,13 @@ from PyQt5 import QtCore, QtGui, QtWidgets
 
 from ...blocks import v4_constants as v4c
 from ...blocks.utils import csv_bytearray2hex, extract_cncomment_xml, MdfException
+from ...mdf import MDF
 from ...signal import Signal
 from ..dialogs.channel_info import ChannelInfoDialog
-from ..utils import (
-    add_children,
-    COLORS,
-    compute_signal,
-    extract_mime_names,
-    get_required_signals,
-    HelperChannel,
-    load_dsp,
-    run_thread_with_progress,
-    setup_progress,
-    TERMINATED,
-)
+from ..utils import compute_signal, extract_mime_names, get_required_signals
 from .numeric import Numeric
 from .plot import Plot
 from .tabular import Tabular
-from .tree import TreeWidget
 
 
 class MdiAreaWidget(QtWidgets.QMdiArea):
@@ -55,7 +43,7 @@ class MdiAreaWidget(QtWidgets.QMdiArea):
             data = e.mimeData()
             if data.hasFormat("application/octet-stream-asammdf"):
                 names = extract_mime_names(data)
-                ret, ok = QtWidgets.QInputDialog.getItem(
+                window_type, ok = QtWidgets.QInputDialog.getItem(
                     None,
                     "Select window type",
                     "Type:",
@@ -64,7 +52,19 @@ class MdiAreaWidget(QtWidgets.QMdiArea):
                     False,
                 )
                 if ok:
-                    self.add_window_request.emit([ret, names])
+                    if window_type == "Plot" and len(names) > 200:
+                        ret = QtWidgets.QMessageBox.question(
+                            self,
+                            "Continue plotting large number of channels?",
+                            "For optimal performance it is advised not plot more than 200 channels. "
+                            f"You are attempting to plot {len(names)} channels.\n"
+                            "Do you wish to continue?",
+                        )
+
+                        if ret != QtWidgets.QMessageBox.Yes:
+                            return
+
+                    self.add_window_request.emit([window_type, names])
 
     def tile_vertically(self):
         sub_windows = self.subWindowList()
@@ -108,6 +108,25 @@ class WithMDIArea:
         self._frameless_windows = False
 
     def add_new_channels(self, names, widget):
+        if isinstance(widget, Plot):
+            ignore_value2text_conversions = False
+            current_count = len(widget.plot.signals)
+            count = len(names)
+            if current_count + count > 200:
+                ret = QtWidgets.QMessageBox.question(
+                    self,
+                    "Continue plotting large number of channels?",
+                    "For optimal performance it is advised not plot more than 200 channels. "
+                    f"You are attempting to add {count} new channels to a plot that already "
+                    f"contains {current_count} channels.\n"
+                    "Do you wish to continue?",
+                )
+
+                if ret != QtWidgets.QMessageBox.Yes:
+                    return
+        else:
+            ignore_value2text_conversions = self.ignore_value2text_conversions
+
         try:
 
             signals_ = [name for name in names if name[1:] != (-1, -1)]
@@ -129,7 +148,7 @@ class WithMDIArea:
 
                 selected_signals = file.mdf.select(
                     uuids_signals,
-                    ignore_value2text_conversions=self.ignore_value2text_conversions,
+                    ignore_value2text_conversions=ignore_value2text_conversions,
                     copy_master=False,
                     validate=True,
                     raw=True,
@@ -345,8 +364,22 @@ class WithMDIArea:
 
             for signal in signals:
                 if len(signal.samples.shape) > 1:
-
-                    signal.samples = csv_bytearray2hex(pd.Series(list(signal.samples)))
+                    if signal.name.endswith(".DataBytes"):
+                        length_name = signal.name.replace(".DataBytes", ".DataLength")
+                        for s in signals:
+                            if s.name == length_name:
+                                length = s.samples
+                                break
+                        else:
+                            if length_name in self.mdf:
+                                length = self.mdf.get(length_name, samples_only=True)[0]
+                            else:
+                                length = None
+                    else:
+                        length = None
+                    signal.samples = csv_bytearray2hex(
+                        pd.Series(list(signal.samples)), length
+                    )
 
                 if signal.name.endswith("CAN_DataFrame.ID"):
                     signal.samples = signal.samples.astype("<u4") & 0x1FFFFFFF
@@ -371,13 +404,19 @@ class WithMDIArea:
                     w.show()
                     self.mdi_area.tileSubWindows()
 
+            if self._frameless_windows:
+                w.setWindowFlags(w.windowFlags() | QtCore.Qt.FramelessWindowHint)
+
+            w.layout().setSpacing(1)
+
             menu = w.systemMenu()
 
             def set_title(mdi):
                 name, ok = QtWidgets.QInputDialog.getText(
-                    None, "Set sub-plot title", "Title:",
+                    None, "Set sub-plot title", "Title:"
                 )
                 if ok and name:
+                    widget = mdi.widget()
                     mdi.setWindowTitle(name)
 
             action = QtWidgets.QAction("Set title", menu)
@@ -409,7 +448,11 @@ class WithMDIArea:
                         event_info["type"] = v4c.EVENT_TYPE_TO_STRING[event.event_type]
                         description = event.name
                         if event.comment:
-                            description += f" ({event.comment})"
+                            try:
+                                comment = extract_cncomment_xml(event.comment)
+                            except:
+                                comment = event.comment
+                            description += f" ({comment})"
                         event_info["description"] = description
                         event_info["index"] = pos
 
@@ -458,6 +501,11 @@ class WithMDIArea:
                     w.show()
                     self.mdi_area.tileSubWindows()
 
+            if self._frameless_windows:
+                w.setWindowFlags(w.windowFlags() | QtCore.Qt.FramelessWindowHint)
+
+            w.layout().setSpacing(1)
+
             plot.hide()
 
             plot.add_new_channels(signals)
@@ -518,13 +566,11 @@ class WithMDIArea:
                 signals = list(computed_signals.values())
                 plot.add_new_channels(signals)
 
-            plot.show()
-
             menu = w.systemMenu()
 
             def set_title(mdi):
                 name, ok = QtWidgets.QInputDialog.getText(
-                    None, "Set sub-plot title", "Title:",
+                    None, "Set sub-plot title", "Title:"
                 )
                 if ok and name:
                     mdi.setWindowTitle(name)
@@ -554,7 +600,9 @@ class WithMDIArea:
             )
 
             plot.show_properties.connect(self._show_info)
+            plot.channel_selection.setCurrentRow(0)
 
+            plot.show()
             self.set_subplots_link(self.subplots_link)
 
         elif window_type == "Tabular":
@@ -576,10 +624,14 @@ class WithMDIArea:
                     self.mdi_area.tileSubWindows()
 
             menu = w.systemMenu()
+            if self._frameless_windows:
+                w.setWindowFlags(w.windowFlags() | QtCore.Qt.FramelessWindowHint)
+
+            w.layout().setSpacing(1)
 
             def set_title(mdi):
                 name, ok = QtWidgets.QInputDialog.getText(
-                    None, "Set sub-plot title", "Title:",
+                    None, "Set sub-plot title", "Title:"
                 )
                 if ok and name:
                     mdi.setWindowTitle(name)
@@ -593,19 +645,12 @@ class WithMDIArea:
             w.setWindowTitle(f"Tabular {self._window_counter}")
             self._window_counter += 1
 
-        if self._frameless_windows:
-            w.setWindowFlags(w.windowFlags() | QtCore.Qt.FramelessWindowHint)
-
-        w.layout().setSpacing(1)
-
-    def get_current_plot(self):
+    def get_current_widget(self):
         mdi = self.mdi_area.activeSubWindow()
         if mdi is not None:
             widget = mdi.widget()
-            if isinstance(widget, Plot):
-                return widget
-            else:
-                return None
+
+            return widget
         else:
             return None
 
@@ -616,17 +661,17 @@ class WithMDIArea:
 
         if window_info["type"] == "Numeric":
             # patterns
-            pattern_info = window_info['configuration'].get('pattern', {})
+            pattern_info = window_info["configuration"].get("pattern", {})
             if pattern_info:
                 required = set()
                 found_signals = []
                 fmt = "phys"
 
-                pattern = pattern_info['pattern']
+                pattern = pattern_info["pattern"]
                 match_type = pattern_info["match_type"]
-                filter_value = pattern_info['filter_value']
-                filter_type = pattern_info['filter_type']
-                raw = pattern_info['raw']
+                filter_value = pattern_info["filter_value"]
+                filter_type = pattern_info["filter_type"]
+                raw = pattern_info["raw"]
 
                 if match_type == "Wildcard":
                     pattern = pattern.replace("*", "_WILDCARD_")
@@ -653,7 +698,7 @@ class WithMDIArea:
                         raw=True,
                     )
 
-                    if filter_type == 'Unspecified':
+                    if filter_type == "Unspecified":
                         keep = psignals
                     else:
 
@@ -674,13 +719,13 @@ class WithMDIArea:
                             else:
                                 samples = sig.samples
 
-                            if filter_type == 'Contains':
+                            if filter_type == "Contains":
                                 try:
                                     if np.any(np.isclose(samples, target)):
                                         keep.append(sig)
                                 except:
                                     continue
-                            elif filter_type == 'Do not contain':
+                            elif filter_type == "Do not contain":
                                 try:
                                     if not np.allclose(samples, target):
                                         keep.append(sig)
@@ -730,7 +775,7 @@ class WithMDIArea:
 
                 found = set(sig.name for sig in signals)
                 not_found = [
-                    Signal([], [], name=name,) for name in sorted(required - found)
+                    Signal([], [], name=name) for name in sorted(required - found)
                 ]
                 uuid = os.urandom(6).hex()
                 for sig in not_found:
@@ -770,7 +815,7 @@ class WithMDIArea:
 
             def set_title(mdi):
                 name, ok = QtWidgets.QInputDialog.getText(
-                    None, "Set sub-plot title", "Title:",
+                    None, "Set sub-plot title", "Title:"
                 )
                 if ok and name:
                     mdi.setWindowTitle(name)
@@ -787,16 +832,16 @@ class WithMDIArea:
 
         elif window_info["type"] == "Plot":
             # patterns
-            pattern_info = window_info['configuration'].get('pattern', {})
+            pattern_info = window_info["configuration"].get("pattern", {})
             if pattern_info:
                 required = set()
                 found_signals = []
 
-                pattern = pattern_info['pattern']
+                pattern = pattern_info["pattern"]
                 match_type = pattern_info["match_type"]
-                filter_value = pattern_info['filter_value']
-                filter_type = pattern_info['filter_type']
-                raw = pattern_info['raw']
+                filter_value = pattern_info["filter_value"]
+                filter_type = pattern_info["filter_type"]
+                raw = pattern_info["raw"]
 
                 if match_type == "Wildcard":
                     pattern = pattern.replace("*", "_WILDCARD_")
@@ -805,7 +850,9 @@ class WithMDIArea:
 
                 try:
                     pattern = re.compile(f"(?i){pattern}")
-                    matches = [name for name in self.mdf.channels_db if pattern.match(name)]
+                    matches = [
+                        name for name in self.mdf.channels_db if pattern.match(name)
+                    ]
                 except:
                     print(format_exc())
                     signals = []
@@ -819,7 +866,7 @@ class WithMDIArea:
                         raw=True,
                     )
 
-                    if filter_type == 'Unspecified':
+                    if filter_type == "Unspecified":
                         keep = psignals
                     else:
 
@@ -831,19 +878,18 @@ class WithMDIArea:
 
                             target = np.ones(size) * filter_value
 
-
                             if not raw:
                                 samples = sig.physical().samples
                             else:
                                 samples = sig.samples
 
-                            if filter_type == 'Contains':
+                            if filter_type == "Contains":
                                 try:
                                     if np.any(np.isclose(samples, target)):
                                         keep.append(sig)
                                 except:
                                     continue
-                            elif filter_type == 'Do not contain':
+                            elif filter_type == "Do not contain":
                                 try:
                                     if not np.allclose(samples, target):
                                         keep.append(sig)
@@ -859,7 +905,9 @@ class WithMDIArea:
 
             else:
 
-                required = set(e["name"] for e in window_info["configuration"]["channels"])
+                required = set(
+                    e["name"] for e in window_info["configuration"]["channels"]
+                )
 
                 found_signals = [
                     channel
@@ -952,7 +1000,9 @@ class WithMDIArea:
                     except:
                         pass
 
-                signals = list(measured_signals.values()) + list(computed_signals.values())
+                signals = list(measured_signals.values()) + list(
+                    computed_signals.values()
+                )
 
             signals = [
                 sig
@@ -978,7 +1028,11 @@ class WithMDIArea:
                         event_info["type"] = v4c.EVENT_TYPE_TO_STRING[event.event_type]
                         description = event.name
                         if event.comment:
-                            description += f" ({event.comment})"
+                            try:
+                                comment = extract_cncomment_xml(event.comment)
+                            except:
+                                comment = event.comment
+                            description += f" ({comment})"
                         event_info["description"] = description
                         event_info["index"] = pos
 
@@ -1011,9 +1065,7 @@ class WithMDIArea:
                 origin = self.files.widget(0).mdf.start_time
 
             found = set(sig.name for sig in signals)
-            not_found = [
-                Signal([], [], name=name,) for name in sorted(required - found)
-            ]
+            not_found = [Signal([], [], name=name) for name in sorted(required - found)]
             uuid = os.urandom(6).hex()
             for sig in not_found:
                 sig.mdf_uuid = uuid
@@ -1062,7 +1114,7 @@ class WithMDIArea:
 
             def set_title(mdi):
                 name, ok = QtWidgets.QInputDialog.getText(
-                    None, "Set sub-plot title", "Title:",
+                    None, "Set sub-plot title", "Title:"
                 )
                 if ok and name:
                     mdi.setWindowTitle(name)
@@ -1109,10 +1161,12 @@ class WithMDIArea:
                         else QtCore.Qt.Unchecked
                     )
                     wid.display.setCheckState(
-                        QtCore.Qt.Checked if description["enabled"] else QtCore.Qt.Unchecked
+                        QtCore.Qt.Checked
+                        if description["enabled"]
+                        else QtCore.Qt.Unchecked
                     )
                 elif pattern_info:
-                    wid.ranges = pattern_info['ranges']
+                    wid.ranges = pattern_info["ranges"]
 
             self.set_subplots_link(self.subplots_link)
 
@@ -1121,16 +1175,16 @@ class WithMDIArea:
 
         elif window_info["type"] == "Tabular":
             # patterns
-            pattern_info = window_info['configuration'].get('pattern', {})
+            pattern_info = window_info["configuration"].get("pattern", {})
             if pattern_info:
                 required = set()
                 found_signals = []
 
-                pattern = pattern_info['pattern']
+                pattern = pattern_info["pattern"]
                 match_type = pattern_info["match_type"]
-                filter_value = pattern_info['filter_value']
-                filter_type = pattern_info['filter_type']
-                raw = pattern_info['raw']
+                filter_value = pattern_info["filter_value"]
+                filter_type = pattern_info["filter_type"]
+                raw = pattern_info["raw"]
 
                 if match_type == "Wildcard":
                     pattern = pattern.replace("*", "_WILDCARD_")
@@ -1157,7 +1211,7 @@ class WithMDIArea:
                         raw=True,
                     )
 
-                    if filter_type == 'Unspecified':
+                    if filter_type == "Unspecified":
                         keep = list(matches)
                     else:
 
@@ -1175,13 +1229,13 @@ class WithMDIArea:
                             else:
                                 samples = sig.samples
 
-                            if filter_type == 'Contains':
+                            if filter_type == "Contains":
                                 try:
                                     if np.any(np.isclose(samples, target)):
                                         keep.append(name)
                                 except:
                                     continue
-                            elif filter_type == 'Do not contain':
+                            elif filter_type == "Do not contain":
                                 try:
                                     if not np.allclose(samples, target):
                                         keep.append(name)
@@ -1246,7 +1300,7 @@ class WithMDIArea:
                 self._window_counter += 1
 
             filter_count = 0
-            available_columns = [signals.index.name,] + list(signals.columns)
+            available_columns = [signals.index.name] + list(signals.columns)
             for filter_info in window_info["configuration"]["filters"]:
                 if filter_info["column"] in available_columns:
                     tabular.add_filter()
@@ -1285,7 +1339,7 @@ class WithMDIArea:
 
             def set_title(mdi):
                 name, ok = QtWidgets.QInputDialog.getText(
-                    None, "Set sub-plot title", "Title:",
+                    None, "Set sub-plot title", "Title:"
                 )
                 if ok and name:
                     mdi.setWindowTitle(name)
@@ -1304,7 +1358,9 @@ class WithMDIArea:
 
         if pattern_info:
             icon = QtGui.QIcon()
-            icon.addPixmap(QtGui.QPixmap(":/filter.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+            icon.addPixmap(
+                QtGui.QPixmap(":/filter.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+            )
             w.setWindowIcon(icon)
 
         w.layout().setSpacing(1)
@@ -1315,8 +1371,8 @@ class WithMDIArea:
 
         self.with_dots = with_dots
 
-        current_plot = self.get_current_plot()
-        if current_plot:
+        current_plot = self.get_current_widget()
+        if current_plot and isinstance(current_plot, Plot):
             current_plot.plot.update_lines(with_dots=with_dots)
 
     def set_subplots(self, option):
@@ -1446,7 +1502,7 @@ class WithMDIArea:
 
     def save_all_subplots(self):
         file_name, _ = QtWidgets.QFileDialog.getSaveFileName(
-            self, "Select output measurement file", "", "MDF version 4 files (*.mf4)",
+            self, "Select output measurement file", "", "MDF version 4 files (*.mf4)"
         )
 
         if file_name:
