@@ -4,7 +4,6 @@ from functools import partial, reduce
 import logging
 import os
 from pathlib import Path
-from struct import unpack
 from time import perf_counter
 
 import numpy as np
@@ -19,6 +18,7 @@ from ..utils import COLORS, extract_mime_names
 from .channel_display import ChannelDisplay
 from .channel_stats import ChannelStats
 from .cursor import Cursor
+from .dict_to_tree import ComputedChannelInfoWindow
 from .formated_axis import FormatedAxis
 from .list import ListWidget
 from .list_item import ListItem
@@ -631,7 +631,11 @@ class PlotSignal(Signal):
                         pos_max = np.nanargmax(samples_)
                         pos_min = np.nanargmin(samples_)
 
-                        pos = sorted((pos_min, pos_max))
+                        pos = (
+                            [pos_min, pos_max]
+                            if pos_min < pos_max
+                            else [pos_max, pos_min]
+                        )
 
                         samples_ = signal_samples[stop_2:stop_][pos]
                         timestamps_ = sig.timestamps[stop_2:stop_][pos]
@@ -651,6 +655,13 @@ class PlotSignal(Signal):
 
     def value_at_timestamp(self, stamp):
         cut = self.cut(stamp, stamp)
+
+        if len(self.timestamps) and self.timestamps[-1] < stamp:
+            cut.samples = self.samples[-1:]
+            cut.phys_samples = self.phys_samples[-1:]
+            cut.raw_samples = self.raw_samples[-1:]
+            cut.timestamps = self.timestamps[-1:]
+
         if self.mode == "raw":
             values = cut.raw_samples
         else:
@@ -1063,12 +1074,11 @@ class Plot(QtWidgets.QWidget):
         key = event.key()
         modifiers = event.modifiers()
         if key == QtCore.Qt.Key_M and modifiers == QtCore.Qt.NoModifier:
-
             ch_size, plt_size, info_size = self.splitter.sizes()
 
             if self.info.isVisible():
                 self.info.hide()
-                self.splitter.setSizes((ch_size, plt_size + info_size, 0,))
+                self.splitter.setSizes((ch_size, plt_size + info_size, 0))
 
             else:
 
@@ -1259,6 +1269,10 @@ class Plot(QtWidgets.QWidget):
         it = ChannelDisplay(sig.uuid, unit, sig.samples.dtype.kind, 3, tooltip, self)
         it.setAttribute(QtCore.Qt.WA_StyledBackground)
 
+        font = QtGui.QFont()
+        font.setItalic(True)
+        it.name.setFont(font)
+
         it.set_name(name)
         it.set_value("")
         it.set_color(sig.color)
@@ -1286,14 +1300,22 @@ class Plot(QtWidgets.QWidget):
         invalid = []
 
         for channel in channels:
-            if np.any(np.diff(channel.timestamps) < 0):
-                invalid.append(channel.name)
+            diff = np.diff(channel.timestamps)
+            invalid_indexes = np.argwhere(diff <= 0).ravel()
+            if len(invalid_indexes):
+                invalid_indexes = invalid_indexes[:10] + 1
+                idx = invalid_indexes[0]
+                ts = channel.timestamps[idx - 1 : idx + 2]
+                invalid.append(
+                    f"{channel.name} @ index {invalid_indexes[:10] - 1} with first time stamp error: {ts}"
+                )
 
         if invalid:
+            errors = "\n".join(invalid)
             QtWidgets.QMessageBox.warning(
                 self,
                 "The following channels do not have monotonous increasing time stamps:",
-                f"The following channels do not have monotonous increasing time stamps:\n{', '.join(invalid)}",
+                f"The following channels do not have monotonous increasing time stamps:\n{errors}",
             )
             self.plot._can_trim = False
 
@@ -1356,6 +1378,11 @@ class Plot(QtWidgets.QWidget):
             it = ChannelDisplay(sig.uuid, sig.unit, kind, 3, tooltip, self)
             it.setAttribute(QtCore.Qt.WA_StyledBackground)
 
+            if sig.computed:
+                font = QtGui.QFont()
+                font.setItalic(True)
+                it.name.setFont(font)
+
             it.set_name(sig.name)
             it.set_value("")
             it.set_color(sig.color)
@@ -1392,7 +1419,7 @@ class Plot(QtWidgets.QWidget):
             channel["color"] = sig.color
             channel["computed"] = sig.computed
             ranges = [
-                {"start": start, "stop": stop, "color": color,}
+                {"start": start, "stop": stop, "color": color}
                 for (start, stop), color in item.ranges.items()
             ]
             channel["ranges"] = ranges
@@ -1446,10 +1473,15 @@ class Plot(QtWidgets.QWidget):
 
     def _show_properties(self, uuid):
         for sig in self.plot.signals:
-            if sig.uuid == uuid and not sig.computed:
-                self.show_properties.emit(
-                    [sig.group_index, sig.channel_index, sig.mdf_uuid]
-                )
+            if sig.uuid == uuid:
+                if sig.computed:
+                    view = ComputedChannelInfoWindow(sig, self)
+                    view.show()
+
+                else:
+                    self.show_properties.emit(
+                        [sig.group_index, sig.channel_index, sig.mdf_uuid]
+                    )
 
     def set_splitter(self, pos, index):
         self.splitter_moved.emit(self, pos)
@@ -1562,13 +1594,17 @@ class _Plot(pg.PlotWidget):
         self.view_boxes = []
         self.curves = []
 
-        self.viewbox.sigResized.connect(self.update_views)
         self._prev_geometry = self.viewbox.sceneBoundingRect()
 
         self.resizeEvent = self._resizeEvent
 
         self._uuid_map = {}
 
+        self._enabled_changed_signals = []
+        self._enable_timer = QtCore.QTimer()
+        self._enable_timer.setSingleShot(True)
+        self._enable_timer.timeout.connect(self._signals_enabled_changed_handler)
+
         if signals:
             self.add_new_channels(signals)
 
@@ -1623,6 +1659,10 @@ class _Plot(pg.PlotWidget):
                 )
                 self.plotItem.addItem(line, ignoreBounds=True)
 
+        self.viewbox.sigResized.connect(self.update_views)
+        if signals:
+            self.update_views()
+
     def update_lines(self, with_dots=None, force=False):
         with_dots_changed = False
 
@@ -1757,7 +1797,6 @@ class _Plot(pg.PlotWidget):
 
         if state in (QtCore.Qt.Checked, True, 1):
             self.signals[index].enable = True
-            self.curves[index].show()
             self.view_boxes[index].setXLink(self.viewbox)
             if self.signals[index].individual_axis:
                 self.axes[index].show()
@@ -1767,7 +1806,6 @@ class _Plot(pg.PlotWidget):
 
         else:
             self.signals[index].enable = False
-            self.curves[index].hide()
             self.view_boxes[index].setXLink(None)
             self.axes[index].hide()
 
@@ -1776,10 +1814,14 @@ class _Plot(pg.PlotWidget):
 
                 if len(self._timebase_db[id(sig.timestamps)]) == 0:
                     del self._timebase_db[id(sig.timestamps)]
-                    self._compute_all_timebase()
             except:
                 pass
 
+        self._enable_timer.start(50)
+
+    def _signals_enabled_changed_handler(self):
+        self._compute_all_timebase()
+        self.update_lines(force=True)
         if self.cursor1:
             self.cursor_move_finished.emit()
 
@@ -2235,6 +2277,7 @@ class _Plot(pg.PlotWidget):
             axis.update()
 
         self.current_uuid = uuid
+        axis.setWidth()
 
     def _clicked(self, event):
         modifiers = QtGui.QApplication.keyboardModifiers()
@@ -2302,6 +2345,8 @@ class _Plot(pg.PlotWidget):
             start_t, stop_t = np.amin(self.all_timebase), np.amax(self.all_timebase)
             self.viewbox.setXRange(start_t, stop_t)
 
+        axis_uuid = None
+
         for index, sig in enumerate(channels, initial_index):
             color = sig.color
 
@@ -2316,6 +2361,7 @@ class _Plot(pg.PlotWidget):
                 axis.text_conversion = sig.conversion
 
             view_box = pg.ViewBox(enableMenu=False)
+            view_box.setGeometry(geometry)
             view_box.disableAutoRange()
 
             axis.linkToView(view_box)
@@ -2356,7 +2402,6 @@ class _Plot(pg.PlotWidget):
             if not sig.empty:
                 view_box.setYRange(sig.min, sig.max, padding=0, update=True)
 
-            view_box.setGeometry(geometry)
             #            (start, stop), _ = self.viewbox.viewRange()
             #            view_box.setXRange(start, stop, padding=0, update=True)
 
@@ -2365,7 +2410,7 @@ class _Plot(pg.PlotWidget):
             view_box.addItem(curve)
 
             if initial_index == 0 and index == 0:
-                self.set_current_uuid(sig.uuid)
+                axis_uuid = sig.uuid
 
         for index, sig in enumerate(channels, initial_index):
             self.view_boxes[index].setXLink(self.viewbox)
@@ -2373,6 +2418,9 @@ class _Plot(pg.PlotWidget):
         for curve in self.curves[initial_index:]:
             curve.show()
 
+        if axis_uuid is not None:
+            self.set_current_uuid(sig.uuid)
+
         return channels
 
     def _compute_all_timebase(self):
@@ -2425,22 +2473,29 @@ class _Plot(pg.PlotWidget):
         needs_timebase_compute = False
 
         indexes = sorted(
-            [(self.signal_by_uuid(uuid)[1], uuid) for uuid in deleted], reverse=True,
+            [(self.signal_by_uuid(uuid)[1], uuid) for uuid in deleted], reverse=True
         )
 
         for i, uuid in indexes:
             item = self.curves.pop(i)
             item.hide()
             item.setParent(None)
-
-            item = self.view_boxes.pop(i)
-            item.hide()
-            item.setParent(None)
+            self.view_boxes[i].removeItem(item)
 
             item = self.axes.pop(i)
+            item.unlinkFromView()
+            self.layout.removeItem(item)
             item.hide()
             item.setParent(None)
 
+            item = self.view_boxes.pop(i)
+            self.layout.removeItem(item)
+            self.scene_.removeItem(item)
+            item.hide()
+            item.setParent(None)
+            item.setXLink(None)
+            item.setYLink(None)
+
             sig = self.signals.pop(i)
 
             if uuid in self.common_axis_items:
