@@ -6,38 +6,92 @@ from traceback import format_exc
 import numpy as np
 import numpy.core.defchararray as npchar
 import pandas as pd
-from PyQt5 import QtCore, QtWidgets
+from PyQt5 import QtCore, QtGui, QtWidgets
 
-from ...blocks.utils import csv_bytearray2hex, csv_int2hex, pandas_query_compatible
+from ...blocks.utils import (
+    csv_bytearray2hex,
+    csv_int2bin,
+    csv_int2hex,
+    pandas_query_compatible,
+)
 from ..ui import resource_rc as resource_rc
 from ..ui.tabular import Ui_TabularDisplay
+from ..utils import run_thread_with_progress
 from .tabular_filter import TabularFilter
 
 logger = logging.getLogger("asammdf.gui")
 LOCAL_TIMEZONE = datetime.datetime.now(datetime.timezone.utc).astimezone().tzinfo
 
 
+class TabularTreeItem(QtWidgets.QTreeWidgetItem):
+    def __init__(self, column_types, as_hex, *args, **kwargs):
+        self.column_types = column_types
+        self.as_hex = as_hex
+        super().__init__(*args, **kwargs)
+
+    def __lt__(self, other):
+        column = self.treeWidget().sortColumn()
+
+        dtype = self.column_types[column]
+
+        if dtype in "ui":
+            if self.as_hex[column]:
+                return int(self.text(column), 16) < int(other.text(column), 16)
+            else:
+                return int(self.text(column)) < int(other.text(column))
+
+        elif dtype == "f":
+            return float(self.text(column)) < float(other.text(column))
+
+        else:
+            return self.text(column) < other.text(column)
+
+
 class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
     add_channels_request = QtCore.pyqtSignal(list)
 
-    def __init__(self, signals=None, start=0, *args, **kwargs):
+    def __init__(self, signals=None, start=0, format="phys", *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.setupUi(self)
 
+        self.tree.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.tree.customContextMenuRequested.connect(self.open_menu)
+
         self.signals_descr = {}
         self.start = start
         self.pattern = {}
+        self.format = format
+        self.format_selection.setCurrentText(format)
 
         if signals is None:
             self.signals = pd.DataFrame()
         else:
+            index = pd.Series(np.arange(len(signals), dtype="u8"), index=signals.index)
+            signals["Index"] = index
+
+            signals["timestamps"] = signals.index
+            signals.set_index(index, inplace=True)
             dropped = {}
 
             for name_ in signals.columns:
                 col = signals[name_]
                 if col.dtype.kind == "O":
-                    #                    dropped[name_] = pd.Series(csv_bytearray2hex(col), index=signals.index)
-                    self.signals_descr[name_] = 1
+                    if (
+                        name_.endswith(".DataBytes")
+                        and name_.replace(".DataBytes", ".DataLength") in signals
+                    ):
+                        dropped[name_] = pd.Series(
+                            csv_bytearray2hex(
+                                col, signals[name_.replace(".DataBytes", ".DataLength")]
+                            ),
+                            index=signals.index,
+                        )
+                    else:
+                        dropped[name_] = pd.Series(
+                            csv_bytearray2hex(col), index=signals.index
+                        )
+                    self.signals_descr[name_] = 0
+
                 elif col.dtype.kind == "S":
                     try:
                         dropped[name_] = pd.Series(
@@ -51,11 +105,21 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
                 else:
                     self.signals_descr[name_] = 0
 
-            signals = signals.drop(columns=list(dropped))
+            signals = signals.drop(columns=["Index", *list(dropped)])
             for name, s in dropped.items():
                 signals[name] = s
 
-            self.signals = signals
+            names = list(signals.columns)
+            names = [
+                "timestamps",
+                *[name for name in names if name.endswith((".ID", ".DataBytes"))],
+                *[
+                    name
+                    for name in names
+                    if name != "timestamps" and not name.endswith((".ID", ".DataBytes"))
+                ],
+            ]
+            self.signals = signals[names]
 
         self.as_hex = [
             name.endswith(
@@ -71,7 +135,7 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
             for name in self.signals.columns
         ]
 
-        self._original_index = self.signals.index.values
+        self._original_timestamps = signals["timestamps"]
 
         self.build(self.signals, True)
 
@@ -88,34 +152,81 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
                 name = name.rsplit(".", 1)[0]
                 prefixes.add(f"{name}.")
 
-        self.prefix.insertItems(0, sorted(prefixes))
+        self.filters.minimal_menu = True
+
+        self.prefix.insertItems(0, sorted(prefixes, key=lambda x: (-len(x), x)))
         self.prefix.setEnabled(False)
 
         self.prefix.currentIndexChanged.connect(self.prefix_changed)
 
+        if prefixes:
+            self.remove_prefix.setCheckState(QtCore.Qt.Checked)
+
         self.tree_scroll.valueChanged.connect(self._display)
         self.tree.verticalScrollBar().valueChanged.connect(self._scroll_tree)
+        self.tree.currentItemChanged.connect(self._scroll_tree)
+        self.format_selection.currentTextChanged.connect(self.set_format)
+
+        self._settings = QtCore.QSettings()
+        integer_mode = self._settings.value("tabular_format", "phys")
+
+        self.format_selection.setCurrentText(integer_mode)
+
+    def _scroll_tree(self, selected_item):
+        count = self.tree.topLevelItemCount()
+        if count <= 1:
+            return
+
+        if isinstance(selected_item, int):
+
+            try:
+                row = int(
+                    selected_item
+                    / self.tree.verticalScrollBar().maximum()
+                    * (count - 1)
+                )
+            except:
+                row = count - 1
+            selected_item = self.tree.topLevelItem(row)
+
+        first = self.tree.topLevelItem(0)
+        last = self.tree.topLevelItem(count - 1)
 
-    def _scroll_tree(self, value):
         if (
-            value == self.tree.verticalScrollBar().minimum()
+            selected_item is first
             and self.tree_scroll.value() != self.tree_scroll.minimum()
         ):
+            current_index = selected_item.text(0)
             self.tree_scroll.setValue(
                 self.tree_scroll.value() - self.tree_scroll.singleStep()
             )
-            self.tree.verticalScrollBar().setValue(
-                self.tree.verticalScrollBar().value()
-                + self.tree.verticalScrollBar().singleStep()
-            )
-        elif value == self.tree.verticalScrollBar().maximum():
+
+            item = self.tree.findItems(current_index, QtCore.Qt.MatchExactly)[0]
+            above = self.tree.itemAbove(item)
+            self.tree.scrollToItem(above, QtWidgets.QAbstractItemView.PositionAtTop)
+            try:
+                item = self.tree.itemBelow(above)
+                self.tree.setCurrentItem(item)
+            except:
+                pass
+
+        elif (
+            selected_item is last
+            and self.tree_scroll.value() != self.tree_scroll.maximum()
+        ):
+            current_index = selected_item.text(0)
             self.tree_scroll.setValue(
                 self.tree_scroll.value() + self.tree_scroll.singleStep()
             )
-            self.tree.verticalScrollBar().setValue(
-                self.tree.verticalScrollBar().value()
-                - self.tree.verticalScrollBar().singleStep()
-            )
+
+            item = self.tree.findItems(current_index, QtCore.Qt.MatchExactly)[0]
+            below = self.tree.itemBelow(item)
+            self.tree.scrollToItem(below, QtWidgets.QAbstractItemView.PositionAtBottom)
+            try:
+                item = self.tree.itemAbove(below)
+                self.tree.setCurrentItem(item)
+            except:
+                pass
 
     def _sort(self, index, mode):
         ascending = mode == QtCore.Qt.AscendingOrder
@@ -203,7 +314,7 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
                     filters.append("!=")
                     filters.append(column_name)
             else:
-                if column_name == df.index.name and df.index.dtype.kind == "M":
+                if column_name == "timestamps" and df["timestamps"].dtype.kind == "M":
 
                     ts = pd.Timestamp(target, tz=LOCAL_TIMEZONE)
                     ts = ts.tz_convert("UTC").to_datetime64()
@@ -217,7 +328,7 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
 
                     if f"{column_name}__as__bytes" not in df.columns:
                         df[f"{column_name}__as__bytes"] = pd.Series(
-                            [bytes(s) for s in df[column_name]], index=df.index,
+                            [bytes(s) for s in df[column_name]], index=df.index
                         )
                     val = bytes.fromhex(target)
 
@@ -277,7 +388,7 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
             for name, s in dropped.items():
                 df[name[dim:]] = s
 
-        names = [df.index.name, *df.columns]
+        names = ["Index", *df.columns]
 
         if reset_header_names:
             self.header_names = names
@@ -303,36 +414,39 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
 
         df = self.df.iloc[max(0, position * 10 - 50) : max(0, position * 10 + 100)]
 
-        if df.index.dtype.kind == "M":
-            index = df.index.tz_localize("UTC").tz_convert(LOCAL_TIMEZONE)
+        if df["timestamps"].dtype.kind == "M":
+            timestamps = (
+                pd.Index(df["timestamps"]).tz_localize("UTC").tz_convert(LOCAL_TIMEZONE)
+            )
         else:
-            index = df.index
-        items = [
-            index.astype(str),
-        ]
+            timestamps = df["timestamps"]
 
-        for i, name in enumerate(df.columns):
+        timestamps = timestamps.astype(str)
+        items = [df.index.astype(str), timestamps]
+
+        for i, name in enumerate(df.columns[1:], 1):
             column = df[name]
             kind = column.dtype.kind
 
-            if self.as_hex[i]:
-                items.append(pd.Series(csv_int2hex(column.astype("<u4"))).values)
-            else:
-
-                if kind in "uif":
-                    items.append(column.astype(str))
-                elif kind == "S":
-                    try:
-                        items.append(npchar.decode(column, "utf-8"))
-                    except:
-                        items.append(npchar.decode(column, "latin-1"))
-                elif kind == "O":
-                    try:
-                        items.append(pd.Series(csv_bytearray2hex(df[name])).values)
-                    except:
-                        items.append(pd.Series(df[name]).values)
+            if kind in "ui":
+                if self.format == "hex":
+                    items.append(pd.Series(csv_int2hex(column)).values)
+                elif self.format == "bin":
+                    items.append(pd.Series(csv_int2bin(column)).values)
                 else:
-                    items.append(column)
+                    items.append(column.astype(str))
+
+            elif kind == "f":
+                items.append(column.astype(str))
+            elif kind == "S":
+                try:
+                    items.append(npchar.decode(column, "utf-8"))
+                except:
+                    items.append(npchar.decode(column, "latin-1"))
+            elif kind == "O":
+                items.append(column)
+            else:
+                items.append(column)
 
         if position == 0:
             self.tree.verticalScrollBar().setSliderPosition(0)
@@ -341,7 +455,11 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
                 self.tree.verticalScrollBar().maximum()
             )
 
-        items = [QtWidgets.QTreeWidgetItem(row) for row in zip(*items)]
+        column_types = ["u", *[df[name].dtype.kind for name in df.columns]]
+
+        as_hex = [False] + self.as_hex
+
+        items = [TabularTreeItem(column_types, as_hex, row) for row in zip(*items)]
 
         self.tree.addTopLevelItems(items)
 
@@ -364,9 +482,12 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
             "filters": [
                 self.filters.itemWidget(self.filters.item(i)).to_config()
                 for i in range(count)
-            ] if not self.pattern else [],
+            ]
+            if not self.pattern
+            else [],
             "time_as_date": self.time_as_date.checkState() == QtCore.Qt.Checked,
             "pattern": self.pattern,
+            "format": self.format,
         }
 
         return config
@@ -393,9 +514,11 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
                 else:
                     filter.validate_target()
 
-            index = pd.to_datetime(self.signals.index + self.start, unit="s")
+            timestamps = pd.to_datetime(
+                self.signals["timestamps"] + self.start, unit="s"
+            )
 
-            self.signals.index = index
+            self.signals["timestamps"] = timestamps
         else:
             for i in range(count):
                 filter = self.filters.itemWidget(self.filters.item(i))
@@ -405,8 +528,7 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
                     filter.column_changed(0)
                 else:
                     filter.validate_target()
-            self.signals.index = self._original_index
-        self.signals.index.name = "timestamps"
+            self.signals["timestamps"] = self._original_timestamps
 
         if self.query.toPlainText():
             self.apply_filters()
@@ -430,3 +552,82 @@ class Tabular(Ui_TabularDisplay, QtWidgets.QWidget):
 
     def prefix_changed(self, index):
         self.remove_prefix_changed(QtCore.Qt.Checked)
+
+    def open_menu(self, position):
+        menu = QtWidgets.QMenu()
+
+        menu.addAction(self.tr("Export to CSV"))
+
+        action = menu.exec_(self.tree.viewport().mapToGlobal(position))
+
+        if action is None:
+            return
+
+        if action.text() == "Export to CSV":
+            file_name, _ = QtWidgets.QFileDialog.getSaveFileName(
+                self,
+                "Select output CSV file",
+                "",
+                "CSV (*.csv)",
+            )
+
+            if file_name:
+                self.progress = 0, 0
+                progress = QtWidgets.QProgressDialog(
+                    f'Data export to CSV file "{file_name}"', "", 0, 0, self.parent()
+                )
+
+                progress.setWindowModality(QtCore.Qt.ApplicationModal)
+                progress.setCancelButton(None)
+                progress.setAutoClose(True)
+                progress.setWindowTitle("Export tabular window to CSV")
+                icon = QtGui.QIcon()
+                icon.addPixmap(
+                    QtGui.QPixmap(":/csv.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
+                )
+                progress.setWindowIcon(icon)
+                progress.show()
+
+                target = self.signals.to_csv
+                kwargs = {
+                    "path_or_buf": file_name,
+                    "index_label": "Index",
+                    "date_format": "%Y-%m-%d %H:%M:%S.%f%z",
+                }
+
+                result = run_thread_with_progress(
+                    self,
+                    target=target,
+                    kwargs=kwargs,
+                    factor=0,
+                    offset=0,
+                    progress=progress,
+                )
+
+                progress.cancel()
+
+    def keyPressEvent(self, event):
+        key = event.key()
+        modifier = event.modifiers()
+
+        if (
+            key in (QtCore.Qt.Key_H, QtCore.Qt.Key_B, QtCore.Qt.Key_P)
+            and modifier == QtCore.Qt.ControlModifier
+        ):
+            if key == QtCore.Qt.Key_H:
+                self.format_selection.setCurrentText("hex")
+            elif key == QtCore.Qt.Key_B:
+                self.format_selection.setCurrentText("bin")
+            else:
+                self.format_selection.setCurrentText("phys")
+
+            event.accept()
+        else:
+            super().keyPressEvent(event)
+
+    def set_format(self, fmt):
+        self.format = fmt
+        self._settings.setValue("tabular_format", fmt)
+        self.build(self.signals)
+        if self.query.toPlainText():
+            self.apply_filters()
