@@ -5,6 +5,7 @@ import logging
 from textwrap import fill
 
 import numpy as np
+from numpy.core.defchararray import encode
 
 from .blocks import v2_v3_blocks as v3b
 from .blocks import v4_blocks as v4b
@@ -92,6 +93,20 @@ class Signal(object):
         else:
             if not isinstance(samples, np.ndarray):
                 samples = np.array(samples)
+                if samples.dtype.kind == "U":
+                    if encoding is None:
+                        encodings = ["utf-8", "latin-1"]
+                    else:
+                        encodings = [encoding, "utf-8", "latin-1"]
+                    for encoding in encodings:
+                        try:
+                            samples = encode(samples, encoding)
+                            break
+                        except:
+                            continue
+                    else:
+                        samples = encode(samples, encodings[0], errors="ignore")
+
             if not isinstance(timestamps, np.ndarray):
                 timestamps = np.array(timestamps, dtype=np.float64)
             if samples.shape[0] != timestamps.shape[0]:
@@ -164,7 +179,7 @@ class Signal(object):
 """
 
     def plot(self, validate=True, index_only=False):
-        """ plot Signal samples. Pyqtgraph is used if it is available; in this
+        """plot Signal samples. Pyqtgraph is used if it is available; in this
         case see the GUI plot documentation to see the available commands
 
         Parameters
@@ -188,7 +203,6 @@ class Signal(object):
         except:
             try:
                 import matplotlib.pyplot as plt
-                from mpl_toolkits.mplot3d import axes3d
                 from matplotlib.widgets import Slider
             except ImportError:
                 logging.warning("Signal plotting requires pyqtgraph or matplotlib")
@@ -700,7 +714,7 @@ class Signal(object):
         return result
 
     def extend(self, other):
-        """ extend signal with samples from another signal
+        """extend signal with samples from another signal
 
         Parameters
         ----------
@@ -763,7 +777,7 @@ class Signal(object):
         return result
 
     def interp(self, new_timestamps, interpolation_mode=0):
-        """ returns a new *Signal* interpolated using the *new_timestamps*
+        """returns a new *Signal* interpolated using the *new_timestamps*
 
         Parameters
         ----------
@@ -781,6 +795,7 @@ class Signal(object):
             new interpolated *Signal*
 
         """
+
         if not len(self.samples) or not len(new_timestamps):
             return Signal(
                 self.samples[:0].copy(),
@@ -814,6 +829,7 @@ class Signal(object):
             else:
 
                 kind = self.samples.dtype.kind
+
                 if kind == "f":
                     s = np.interp(new_timestamps, self.timestamps, self.samples)
 
@@ -827,6 +843,12 @@ class Signal(object):
                     else:
                         invalidation_bits = None
                 elif kind in "ui":
+                    if interpolation_mode == 0:
+                        if self.raw and self.conversion:
+                            kind = self.conversion.convert(self.samples[:1]).dtype.kind
+                            if kind == "f":
+                                interpolation_mode = 1
+
                     if interpolation_mode == 1:
                         s = np.interp(
                             new_timestamps, self.timestamps, self.samples
@@ -883,7 +905,7 @@ class Signal(object):
             )
 
     def __apply_func(self, other, func_name):
-        """ delegate operations to the *samples* attribute, but in a time
+        """delegate operations to the *samples* attribute, but in a time
         correct manner by considering the *timestamps*
 
         """
@@ -892,29 +914,32 @@ class Signal(object):
             if len(self) and len(other):
                 start = max(self.timestamps[0], other.timestamps[0])
                 stop = min(self.timestamps[-1], other.timestamps[-1])
-                s1 = self.cut(start, stop)
-                s2 = other.cut(start, stop)
+                s1 = self.physical().cut(start, stop)
+                s2 = other.physical().cut(start, stop)
             else:
                 s1 = self
                 s2 = other
             time = np.union1d(s1.timestamps, s2.timestamps)
-            s = self.interp(time).samples
-            o = other.interp(time).samples
+            s = s1.interp(time).samples
+            o = s2.interp(time).samples
             func = getattr(s, func_name)
+            conversion = None
             s = func(o)
         elif other is None:
             s = self.samples
+            conversion = self.conversion
             time = self.timestamps
         else:
             func = getattr(self.samples, func_name)
             s = func(other)
+            conversion = self.conversion
             time = self.timestamps
         return Signal(
             samples=s,
             timestamps=time,
             unit=self.unit,
             name=self.name,
-            conversion=self.conversion,
+            conversion=conversion,
             raw=self.raw,
             master_metadata=self.master_metadata,
             display_name=self.display_name,
@@ -1100,7 +1125,7 @@ class Signal(object):
         self.samples[idx] = val
 
     def astype(self, np_type):
-        """ returns new *Signal* with samples of dtype *np_type*
+        """returns new *Signal* with samples of dtype *np_type*
 
         Parameters
         ----------
@@ -1169,7 +1194,7 @@ class Signal(object):
         )
 
     def validate(self, copy=True):
-        """ appply invalidation bits if they are available for this signal
+        """appply invalidation bits if they are available for this signal
 
         Parameters
         ----------
