@@ -57,6 +57,8 @@ class TestMDF(unittest.TestCase):
         with self.assertRaises(MdfException):
             MDF(mdf)
 
+        mdf.close()
+
     def test_wrong_header_version(self):
         mdf = BytesIO(
             b"MDF     AAAA    amdf500d\x00\x00\x00\x00\x9f\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
@@ -64,6 +66,8 @@ class TestMDF(unittest.TestCase):
         with self.assertRaises(MdfException):
             MDF(mdf)
 
+        mdf.close()
+
     def test_read(self):
         print("MDF read big files")
         for input_file in Path(TestMDF.tempdir_general.name).iterdir():
@@ -147,6 +151,9 @@ class TestMDF(unittest.TestCase):
                                 if not cond:
                                     print(i, j, vals, target, len(vals), len(target))
                                 self.assertTrue(cond)
+
+                if isinstance(inp, BytesIO):
+                    inp.close()
             self.assertTrue(equal)
 
     def test_read_arrays(self):
@@ -247,6 +254,9 @@ class TestMDF(unittest.TestCase):
                                     print(vals)
                                     1 / 0
 
+                if isinstance(inp, BytesIO):
+                    inp.close()
+
             self.assertTrue(equal)
 
     def test_read_demo(self):
@@ -275,10 +285,15 @@ class TestMDF(unittest.TestCase):
                     for signal in signals:
                         name = signal.stem
                         target = np.load(signal)
-                        values = input_file.get(name).samples
+                        values = input_file.get(
+                            name, *input_file.whereis(name)[0]
+                        ).samples
 
                         self.assertTrue(np.array_equal(target, values))
 
+                if isinstance(inp, BytesIO):
+                    inp.close()
+
     def test_convert(self):
         print("MDF convert big files tests")
 
@@ -289,11 +304,13 @@ class TestMDF(unittest.TestCase):
 
                     with MDF(input_file) as mdf:
                         mdf.configure(read_fragment_size=8000)
-                        outfile = mdf.convert(out).save(
+                        converted = mdf.convert(out)
+                        outfile = converted.save(
                             Path(TestMDF.tempdir.name) / f"tmp_convert_{out}",
                             overwrite=True,
                             compression=compression,
                         )
+                        converted.close()
 
                     equal = True
 
@@ -428,19 +445,24 @@ class TestMDF(unittest.TestCase):
                     for out in SUPPORTED_VERSIONS:
                         print(file, out, type(inp))
 
-                    outfile = input_file.convert(out).save(
-                        Path(TestMDF.tempdir_demo.name) / "tmp", overwrite=True,
+                    converted = input_file.convert(out)
+                    outfile = converted.save(
+                        Path(TestMDF.tempdir_demo.name) / "tmp", overwrite=True
                     )
+                    converted.close()
 
                     with MDF(outfile, use_display_names=True) as mdf:
 
                         for signal in signals:
                             name = signal.stem
                             target = np.load(signal)
-                            values = mdf.get(name).samples
+                            values = mdf.get(name, *mdf.whereis(name)[0]).samples
 
                             self.assertTrue(np.array_equal(target, values))
 
+                if isinstance(inp, BytesIO):
+                    inp.close()
+
     def test_cut(self):
         print("MDF cut big files tests")
 
@@ -451,62 +473,58 @@ class TestMDF(unittest.TestCase):
                 for compression in range(3):
                     print(input_file)
 
-                    outfile0 = MDF(input_file)
-                    outfile0.configure(read_fragment_size=8000)
-                    outfile0 = outfile0.cut(
+                    mdf = MDF(input_file)
+
+                    mdf.configure(read_fragment_size=8000)
+                    cut = mdf.cut(
                         stop=-1, whence=whence, include_ends=False
-                    ).save(
-                        Path(TestMDF.tempdir.name) / "tmp0",
-                        overwrite=True,
-                        compression=compression,
                     )
+                    outfile0 = cut.save(Path(TestMDF.tempdir.name) / "tmp0", overwrite=True)
+                    cut.close()
 
-                    outfile1 = MDF(input_file)
-                    outfile1.configure(read_fragment_size=8000)
-                    outfile1 = outfile1.cut(
+                    mdf.configure(read_fragment_size=8000)
+                    cut = mdf.cut(
                         stop=105, whence=whence, include_ends=False
-                    ).save(
-                        Path(TestMDF.tempdir.name) / "tmp1",
-                        overwrite=True,
-                        compression=compression,
                     )
+                    outfile1 = cut.save(Path(TestMDF.tempdir.name) / "tmp1", overwrite=True)
+                    cut.close()
 
-                    outfile2 = MDF(input_file)
-                    outfile2.configure(read_fragment_size=8000)
-                    outfile2 = outfile2.cut(
+                    mdf.configure(read_fragment_size=8000)
+                    cut = mdf.cut(
                         start=105.1, stop=201, whence=whence, include_ends=False
-                    ).save(
-                        Path(TestMDF.tempdir.name) / "tmp2",
-                        overwrite=True,
-                        compression=compression,
                     )
+                    outfile2 = cut.save(Path(TestMDF.tempdir.name) / "tmp2", overwrite=True)
+                    cut.close()
 
-                    outfile3 = MDF(input_file)
-                    outfile3.configure(read_fragment_size=8000)
-                    outfile3 = outfile3.cut(
+                    mdf.configure(read_fragment_size=8000)
+                    cut = mdf.cut(
                         start=201.1, whence=whence, include_ends=False
-                    ).save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
+                    )
+                    outfile3 = cut.save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
+                    cut.close()
 
-                    outfile4 = MDF(input_file)
-                    outfile4.configure(read_fragment_size=8000)
-                    outfile4 = outfile4.cut(
+                    mdf.configure(read_fragment_size=8000)
+                    cut = mdf.cut(
                         start=7000, whence=whence, include_ends=False
-                    ).save(
-                        Path(TestMDF.tempdir.name) / "tmp4",
-                        overwrite=True,
-                        compression=compression,
+                    )
+                    outfile4 = cut.save(Path(TestMDF.tempdir.name) / "tmp4", overwrite=True)
+                    cut.close()
+
+                    concatenated = MDF.concatenate(
+                        [outfile0, outfile1, outfile2, outfile3, outfile4],
+                        version=mdf.version,
+                        sync=whence,
                     )
 
-                    outfile = MDF.concatenate(
-                        [outfile0, outfile1, outfile2, outfile3, outfile4],
-                        version=MDF(input_file).version,
-                        sync=whence,
-                    ).save(
+                    outfile = concatenated.save(
                         Path(TestMDF.tempdir.name) / "tmp_cut",
                         overwrite=True,
                         compression=compression,
                     )
 
+                    mdf.close()
+                    concatenated.close()
+
                     with MDF(outfile) as mdf:
 
                         for i, group in enumerate(mdf.groups):
@@ -619,25 +637,34 @@ class TestMDF(unittest.TestCase):
             for whence in (0, 1):
                 print(input_file, whence)
 
-                outfile1 = MDF(input_file)
-                outfile1.configure(read_fragment_size=8000)
-                outfile1 = outfile1.cut(
-                    stop=105.5, whence=whence, include_ends=False
-                ).save(Path(TestMDF.tempdir.name) / "tmp1", overwrite=True)
-                outfile2 = MDF(input_file)
-                outfile2.configure(read_fragment_size=8000)
-                outfile2 = outfile2.cut(
-                    start=105.5, stop=201.5, whence=whence, include_ends=False
-                ).save(Path(TestMDF.tempdir.name) / "tmp2", overwrite=True)
-                outfile3 = MDF(input_file)
-                outfile3.configure(read_fragment_size=8000)
-                outfile3 = outfile3.cut(
-                    start=201.5, whence=whence, include_ends=False
-                ).save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
+                mdf = MDF(input_file)
 
-                outfile = MDF.concatenate(
-                    [outfile1, outfile2, outfile3], MDF(input_file).version
-                ).save(Path(TestMDF.tempdir.name) / "tmp_cut", overwrite=True)
+                mdf.configure(read_fragment_size=8000)
+                cut = mdf.cut(
+                    stop=105.5, whence=whence, include_ends=False
+                )
+                outfile1 = cut.save(Path(TestMDF.tempdir.name) / "tmp1", overwrite=True)
+                cut.close()
+
+                cut = mdf.cut(
+                    start=105.5, stop=201.5, whence=whence, include_ends=False
+                )
+                outfile2 = cut.save(Path(TestMDF.tempdir.name) / "tmp2", overwrite=True)
+                cut.close()
+
+                cut = mdf.cut(
+                    start=201.5, whence=whence, include_ends=False
+                )
+                outfile3 = cut.save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
+                cut.close()
+
+                concatenated = MDF.concatenate(
+                    [outfile1, outfile2, outfile3], mdf.version
+                )
+                outfile = concatenated.save(Path(TestMDF.tempdir.name) / "tmp_cut", overwrite=True)
+
+                mdf.close()
+                concatenated.close()
 
                 equal = True
 
@@ -664,7 +691,7 @@ class TestMDF(unittest.TestCase):
                                 types = np.dtype(types)
 
                                 vals = mdf.get(
-                                    "Channel_{}".format(j), group=i, samples_only=True,
+                                    "Channel_{}".format(j), group=i, samples_only=True
                                 )[0]
                                 target = [arr * j for arr in samples]
                                 target = np.core.records.fromarrays(target, dtype=types)
@@ -693,7 +720,7 @@ class TestMDF(unittest.TestCase):
                                 types = np.dtype(types)
 
                                 vals = mdf.get(
-                                    "Channel_{}".format(j), group=i, samples_only=True,
+                                    "Channel_{}".format(j), group=i, samples_only=True
                                 )[0]
                                 target = [samples * j]
                                 target = np.core.records.fromarrays(target, dtype=types)
@@ -729,7 +756,7 @@ class TestMDF(unittest.TestCase):
                                 types = np.dtype(types)
 
                                 vals = mdf.get(
-                                    "Channel_{}".format(j), group=i, samples_only=True,
+                                    "Channel_{}".format(j), group=i, samples_only=True
                                 )[0]
                                 target = [arr * j for arr in samples]
                                 target = np.core.records.fromarrays(target, dtype=types)
@@ -764,36 +791,54 @@ class TestMDF(unittest.TestCase):
                     for whence in (0, 1):
                         print(file, whence)
 
-                        outfile1 = input_file.cut(
+                        cut = input_file.cut(
                             stop=2, whence=whence, include_ends=False
-                        ).save(Path(TestMDF.tempdir.name) / "tmp1", overwrite=True)
-                        outfile2 = input_file.cut(
-                            start=2, stop=6, whence=whence, include_ends=False
-                        ).save(Path(TestMDF.tempdir.name) / "tmp2", overwrite=True)
-                        outfile3 = input_file.cut(
-                            start=6, whence=whence, include_ends=False
-                        ).save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
+                        )
+                        outfile1 = cut.save(Path(TestMDF.tempdir.name) / "tmp1", overwrite=True)
+                        cut.close()
 
-                        outfile = MDF.concatenate(
+                        cut = input_file.cut(
+                            start=2, stop=6, whence=whence, include_ends=False
+                        )
+                        outfile2 = cut.save(Path(TestMDF.tempdir.name) / "tmp2", overwrite=True)
+                        cut.close()
+
+                        cut = input_file.cut(
+                            start=6, whence=whence, include_ends=False
+                        )
+                        outfile3 = cut.save(Path(TestMDF.tempdir.name) / "tmp3", overwrite=True)
+                        cut.close()
+
+                        concatenated = MDF.concatenate(
                             [outfile1, outfile2, outfile3],
                             version=input_file.version,
                             use_display_names=True,
-                        ).save(Path(TestMDF.tempdir.name) / "tmp", overwrite=True)
+                        )
+
+                        outfile = concatenated.save(Path(TestMDF.tempdir.name) / "tmp", overwrite=True)
 
                         print("OUT", outfile)
+                        concatenated.close()
 
                         with MDF(outfile, use_display_names=True) as mdf2:
 
                             for signal in signals:
                                 target = np.load(signal)
-                                sig = mdf2.get(signal.stem)
-                                timestamps = input_file.get(signal.stem).timestamps
+                                sig = mdf2.get(
+                                    signal.stem, *mdf2.whereis(signal.stem)[0]
+                                )
+                                timestamps = input_file.get(
+                                    signal.stem, *input_file.whereis(signal.stem)[0]
+                                ).timestamps
 
                                 self.assertTrue(np.array_equal(sig.samples, target))
                                 self.assertTrue(
                                     np.array_equal(timestamps, sig.timestamps)
                                 )
 
+                if isinstance(inp, BytesIO):
+                    inp.close()
+
     def test_filter(self):
 
         print("MDF read tests")
@@ -836,6 +881,11 @@ class TestMDF(unittest.TestCase):
                         filtered = filtered_mdf.get(name)
                         self.assertTrue(np.array_equal(target, filtered.samples))
 
+                    filtered_mdf.close()
+
+                if isinstance(inp, BytesIO):
+                    inp.close()
+
     def test_select(self):
         print("MDF select tests")
 
@@ -877,6 +927,9 @@ class TestMDF(unittest.TestCase):
                         target = np.load(signals[name])
                         self.assertTrue(np.array_equal(target, sig.samples))
 
+                if isinstance(inp, BytesIO):
+                    inp.close()
+
     def test_scramble(self):
         print("MDF scramble tests")
 
@@ -904,6 +957,8 @@ class TestMDF(unittest.TestCase):
         for i, mdf_df in enumerate(mdf.iter_groups()):
             self.assertTrue(mdf_df.equals(dfs[i]))
 
+        mdf.close()
+
     def test_resample_raster_0(self):
         sigs = [
             Signal(
@@ -920,6 +975,8 @@ class TestMDF(unittest.TestCase):
         with self.assertRaises(AssertionError):
             mdf = mdf.resample(raster=0)
 
+        mdf.close()
+
     def test_resample(self):
         raster = 1.33
         sigs = [
@@ -933,7 +990,8 @@ class TestMDF(unittest.TestCase):
 
         mdf = MDF()
         mdf.append(sigs)
-        mdf = mdf.resample(raster=raster)
+        resampled = mdf.resample(raster=raster)
+        mdf.close()
 
         target_timestamps = np.arange(0, 1500, 1.33)
         target_samples = np.concatenate(
@@ -944,10 +1002,12 @@ class TestMDF(unittest.TestCase):
             ]
         )
 
-        for i, sig in enumerate(mdf.iter_channels(skip_master=True)):
+        for i, sig in enumerate(resampled.iter_channels(skip_master=True)):
             self.assertTrue(np.array_equal(sig.timestamps, target_timestamps))
             self.assertTrue(np.allclose(sig.samples, target_samples))
 
+        resampled.close()
+
     def test_to_dataframe(self):
         dfs = [
             DataFrame(
@@ -971,6 +1031,7 @@ class TestMDF(unittest.TestCase):
         target = DataFrame(target)
 
         self.assertTrue(target.equals(mdf.to_dataframe()))
+        mdf.close()
 
 
 if __name__ == "__main__":
