@@ -31,7 +31,7 @@ class TestSignal(unittest.TestCase):
             Signal(np.array([]), np.array([]))
 
     def test_cut_int(self):
-        s = Signal(np.arange(5), np.arange(5, dtype="<f8"), name="S",)
+        s = Signal(np.arange(5), np.arange(5, dtype="<f8"), name="S")
 
         res = s.cut()
         self.assertTrue(np.array_equal(np.arange(5), res.samples))
@@ -224,7 +224,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(np.array([], dtype="<f8"), res.timestamps))
 
     def test_cut_float(self):
-        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S",)
+        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         res = s.cut()
         self.assertTrue(np.array_equal(np.arange(5), res.samples))
@@ -417,7 +417,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(np.array([], dtype="<f8"), res.timestamps))
 
     def test_add(self):
-        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S",)
+        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         target = np.arange(0, 10, 2, dtype="<f4")
 
@@ -429,7 +429,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(res.samples, target))
 
         # + 2
-        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S",)
+        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         target = np.arange(2, 7, dtype="<f4")
 
@@ -444,7 +444,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(res.samples, target))
 
     def test_sub(self):
-        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S",)
+        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         target = np.zeros(5, dtype="<f4")
 
@@ -456,7 +456,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(res.samples, target))
 
         # - 2
-        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S",)
+        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         target = np.arange(-2, 3, dtype="<f4")
 
@@ -471,7 +471,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(res.samples, target))
 
     def test_mul(self):
-        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S",)
+        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         target = np.arange(5, dtype="<f4") ** 2
 
@@ -482,7 +482,7 @@ class TestSignal(unittest.TestCase):
         res = s
         self.assertTrue(np.array_equal(res.samples, target))
 
-        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S",)
+        s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
         target = np.arange(0, 10, 2, dtype="<f4")
 
         res = s * 2
@@ -496,9 +496,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(res.samples, target))
 
     def test_div(self):
-        s = Signal(
-            np.arange(1, 5, dtype="<f4"), np.arange(1, 5, dtype="<f8"), name="S",
-        )
+        s = Signal(np.arange(1, 5, dtype="<f4"), np.arange(1, 5, dtype="<f8"), name="S")
 
         target = np.ones(4, dtype="<f4")
 
@@ -509,9 +507,7 @@ class TestSignal(unittest.TestCase):
         res = s
         self.assertTrue(np.array_equal(res.samples, target))
 
-        s = Signal(
-            np.arange(1, 5, dtype="<f4"), np.arange(1, 5, dtype="<f8"), name="S",
-        )
+        s = Signal(np.arange(1, 5, dtype="<f4"), np.arange(1, 5, dtype="<f8"), name="S")
         target = np.arange(2, 10, 2, dtype="<f4")
 
         res = 1 / (0.5 / s)
@@ -522,9 +518,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal(res.samples, target))
 
     def test_pow(self):
-        s = Signal(
-            np.arange(1, 5, dtype="<f4"), np.arange(1, 5, dtype="<f8"), name="S",
-        )
+        s = Signal(np.arange(1, 5, dtype="<f4"), np.arange(1, 5, dtype="<f8"), name="S")
 
         target = np.arange(1, 5, dtype="<f4") ** 3
 
